@@ -49,7 +49,7 @@ LinkedObject *LinkedAllocator::get(timeout_t timeout)
     LinkedObject *node = NULL;
 
     if(timeout && timeout != Timer::inf)
-        gettimeout(timeout, &ts);
+        set(&ts, timeout);
 
     lock();
     while(!freelist && rtn) {
@@ -104,13 +104,13 @@ Conditional()
 {
     assert(osize > 0 && c > 0);
 
-    size = osize * c;
+    bufsize = osize * c;
     objsize = osize;
-    count = 0;
+    objcount = 0;
     limit = c;
 
     if(osize) {
-        buf = (char *)malloc(size);
+        buf = (char *)malloc(bufsize);
         crit(buf != NULL, "buffer alloc failed");
     }
     else
@@ -126,7 +126,7 @@ Buffer::~Buffer()
     buf = NULL;
 }
 
-unsigned Buffer::getCount(void)
+unsigned Buffer::count(void)
 {
     unsigned bcount = 0;
 
@@ -134,14 +134,14 @@ unsigned Buffer::getCount(void)
     if(tail > head)
         bcount = (unsigned)((size_t)(tail - head) / objsize);
     else if(head > tail)
-        bcount = (unsigned)((((buf + size) - head) + (tail - buf)) / objsize);
+        bcount = (unsigned)((((buf + bufsize) - head) + (tail - buf)) / objsize);
     unlock();
     return bcount;
 }
 
-unsigned Buffer::getSize(void)
+unsigned Buffer::size(void)
 {
-    return size / objsize;
+    return bufsize / objsize;
 }
 
 void *Buffer::get(void)
@@ -149,26 +149,31 @@ void *Buffer::get(void)
     caddr_t dbuf;
 
     lock();
-    while(!count)
+    while(!objcount)
         wait();
     dbuf = head;
     unlock();
     return dbuf;
 }
 
+void *Buffer::invalid(void) const
+{
+    return NULL;
+}
+
 void *Buffer::peek(unsigned offset)
 {
     caddr_t dbuf;
 
     lock();
-    if(offset >= count) {
+    if(offset >= objcount) {
         unlock();
-        return NULL;
+        return invalid();
     }
 
     dbuf = head + (objsize * offset);
-    if(dbuf >= buf + size)
-        dbuf -= size;
+    if(dbuf >= buf + bufsize)
+        dbuf -= bufsize;
     unlock();
     return dbuf;
 }
@@ -202,10 +207,10 @@ void *Buffer::get(timeout_t timeout)
     bool rtn = true;
 
     if(timeout && timeout != Timer::inf)
-        gettimeout(timeout, &ts);
+        set(&ts, timeout);
 
     lock();
-    while(!count && rtn) {
+    while(!objcount && rtn) {
         if(timeout == Timer::inf)
             wait();
         else if(timeout)
@@ -213,7 +218,7 @@ void *Buffer::get(timeout_t timeout)
         else
             rtn = false;
     }
-    if(count && rtn)
+    if(objcount && rtn)
         dbuf = head;
     unlock();
     return dbuf;
@@ -223,9 +228,9 @@ void Buffer::release(void)
 {
     lock();
     head += objsize;
-    if(head >= buf + size)
+    if(head >= buf + bufsize)
         head = buf;
-    --count;
+    --objcount;
     signal();
     unlock();
 }
@@ -235,13 +240,13 @@ void Buffer::put(void *dbuf)
     assert(dbuf != NULL);
 
     lock();
-    while(count == limit)
+    while(objcount == limit)
         wait();
     memcpy(tail, dbuf, objsize);
     tail += objsize;
-    if(tail >= (buf + size))
+    if(tail >= (buf + bufsize))
         tail = buf;
-    ++count;
+    ++objcount;
     signal();
     unlock();
 }
@@ -254,10 +259,10 @@ bool Buffer::put(void *dbuf, timeout_t timeout)
     struct timespec ts;
 
     if(timeout && timeout != Timer::inf)
-        gettimeout(timeout, &ts);
+        set(&ts, timeout);
 
     lock();
-    while(count == limit && rtn) {
+    while(objcount == limit && rtn) {
         if(timeout == Timer::inf)
             wait();
         else if(timeout)
@@ -265,12 +270,12 @@ bool Buffer::put(void *dbuf, timeout_t timeout)
         else
             rtn = false;
     }
-    if(rtn && count < limit) {
+    if(rtn && objcount < limit) {
         memcpy(tail, dbuf, objsize);
         tail += objsize;
-        if(tail >= (buf + size))
+        if(tail >= (buf + bufsize))
             tail = 0;
-        ++count;
+        ++objcount;
         signal();
     }
     unlock();
@@ -300,7 +305,7 @@ bool Buffer::operator!()
     return rtn;
 }
 
-queue::member::member(queue *q, ObjectProtocol *o) :
+Queue::member::member(Queue *q, ObjectProtocol *o) :
 OrderedObject(q)
 {
     assert(o != NULL);
@@ -309,7 +314,7 @@ OrderedObject(q)
     object = o;
 }
 
-queue::queue(mempager *p, size_t size) :
+Queue::Queue(mempager *p, size_t size) :
 OrderedIndex(), Conditional()
 {
     assert(size > 0);
@@ -320,7 +325,7 @@ OrderedIndex(), Conditional()
     limit = size;
 }
 
-queue::~queue()
+Queue::~Queue()
 {
     linked_pointer<member> mp;
     OrderedObject *next;
@@ -343,7 +348,7 @@ queue::~queue()
     }
 }
 
-bool queue::remove(ObjectProtocol *o)
+bool Queue::remove(ObjectProtocol *o)
 {
     assert(o != NULL);
 
@@ -367,7 +372,7 @@ bool queue::remove(ObjectProtocol *o)
     return rtn;
 }
 
-ObjectProtocol *queue::lifo(timeout_t timeout)
+ObjectProtocol *Queue::lifo(timeout_t timeout)
 {
     struct timespec ts;
     bool rtn = true;
@@ -375,7 +380,7 @@ ObjectProtocol *queue::lifo(timeout_t timeout)
     ObjectProtocol *obj = NULL;
 
     if(timeout && timeout != Timer::inf)
-        gettimeout(timeout, &ts);
+        set(&ts, timeout);
 
     lock();
     while(!tail && rtn) {
@@ -388,7 +393,7 @@ ObjectProtocol *queue::lifo(timeout_t timeout)
     }
     if(rtn && tail) {
         --used;
-        member = static_cast<queue::member *>(tail);
+        member = static_cast<Queue::member *>(tail);
         obj = member->object;
         member->delist(this);
         member->LinkedObject::enlist(&freelist);
@@ -399,7 +404,7 @@ ObjectProtocol *queue::lifo(timeout_t timeout)
     return obj;
 }
 
-ObjectProtocol *queue::fifo(timeout_t timeout)
+ObjectProtocol *Queue::fifo(timeout_t timeout)
 {
     bool rtn = true;
     struct timespec ts;
@@ -407,7 +412,7 @@ ObjectProtocol *queue::fifo(timeout_t timeout)
     ObjectProtocol *obj = NULL;
 
     if(timeout && timeout != Timer::inf)
-        gettimeout(timeout, &ts);
+        set(&ts, timeout);
 
     lock();
     while(rtn && !head) {
@@ -434,7 +439,12 @@ ObjectProtocol *queue::fifo(timeout_t timeout)
     return obj;
 }
 
-ObjectProtocol *queue::peek(unsigned back)
+ObjectProtocol *Queue::invalid(void) const
+{
+    return NULL;
+}
+
+ObjectProtocol *Queue::get(unsigned back)
 {
     linked_pointer<member> node;
     ObjectProtocol *obj;
@@ -445,7 +455,7 @@ ObjectProtocol *queue::peek(unsigned back)
 
     do {
         if(!is(node)) {
-            obj = NULL;
+            obj = invalid();
             break;
         }
         obj = node->object;
@@ -457,7 +467,7 @@ ObjectProtocol *queue::peek(unsigned back)
     return obj;
 }
 
-bool queue::post(ObjectProtocol *object, timeout_t timeout)
+bool Queue::post(ObjectProtocol *object, timeout_t timeout)
 {
     assert(object != NULL);
 
@@ -466,7 +476,7 @@ bool queue::post(ObjectProtocol *object, timeout_t timeout)
     LinkedObject *mem;
 
     if(timeout && timeout != Timer::inf)
-        gettimeout(timeout, &ts);
+        set(&ts, timeout);
 
     lock();
     while(rtn && limit && used == limit) {
@@ -500,17 +510,17 @@ bool queue::post(ObjectProtocol *object, timeout_t timeout)
     return true;
 }
 
-size_t queue::getCount(void)
+size_t Queue::count(void)
 {
-    size_t count;
+    size_t qcount;
     lock();
-    count = used;
+    qcount = used;
     unlock();
-    return count;
+    return qcount;
 }
 
 
-stack::member::member(stack *S, ObjectProtocol *o) :
+Stack::member::member(Stack *S, ObjectProtocol *o) :
 LinkedObject((&S->usedlist))
 {
     assert(o != NULL);
@@ -519,7 +529,7 @@ LinkedObject((&S->usedlist))
     object = o;
 }
 
-stack::stack(mempager *p, size_t size) :
+Stack::Stack(mempager *p, size_t size) :
 Conditional()
 {
     assert(size > 0);
@@ -530,7 +540,7 @@ Conditional()
     used = 0;
 }
 
-stack::~stack()
+Stack::~Stack()
 {
     linked_pointer<member> mp;
     LinkedObject *next;
@@ -553,7 +563,7 @@ stack::~stack()
     }
 }
 
-bool stack::remove(ObjectProtocol *o)
+bool Stack::remove(ObjectProtocol *o)
 {
     assert(o != NULL);
 
@@ -577,7 +587,12 @@ bool stack::remove(ObjectProtocol *o)
     return rtn;
 }
 
-ObjectProtocol *stack::peek(unsigned back)
+ObjectProtocol *Stack::invalid(void) const
+{
+    return NULL;
+}
+
+ObjectProtocol *Stack::get(unsigned back)
 {
     linked_pointer<member> node;
     ObjectProtocol *obj;
@@ -587,7 +602,7 @@ ObjectProtocol *stack::peek(unsigned back)
 
     do {
         if(!is(node)) {
-            obj = NULL;
+            obj = invalid();
             break;
         }
         obj = node->object;
@@ -599,7 +614,7 @@ ObjectProtocol *stack::peek(unsigned back)
     return obj;
 }
 
-ObjectProtocol *stack::pull(timeout_t timeout)
+const ObjectProtocol *Stack::peek(timeout_t timeout)
 {
     bool rtn = true;
     struct timespec ts;
@@ -607,7 +622,7 @@ ObjectProtocol *stack::pull(timeout_t timeout)
     ObjectProtocol *obj = NULL;
 
     if(timeout && timeout != Timer::inf)
-        gettimeout(timeout, &ts);
+        set(&ts, timeout);
 
     lock();
     while(rtn && !usedlist) {
@@ -623,7 +638,40 @@ ObjectProtocol *stack::pull(timeout_t timeout)
         return NULL;
     }
     if(usedlist) {
-        member = static_cast<stack::member *>(usedlist);
+        member = static_cast<Stack::member *>(usedlist);
+        obj = member->object;
+    }
+    if(rtn)
+        signal();
+    unlock();
+    return obj;
+}
+
+ObjectProtocol *Stack::pull(timeout_t timeout)
+{
+    bool rtn = true;
+    struct timespec ts;
+    member *member;
+    ObjectProtocol *obj = NULL;
+
+    if(timeout && timeout != Timer::inf)
+        set(&ts, timeout);
+
+    lock();
+    while(rtn && !usedlist) {
+        if(timeout == Timer::inf)
+            Conditional::wait();
+        else if(timeout)
+            rtn = Conditional::wait(&ts);
+        else
+            rtn = false;
+    }
+    if(!rtn) {
+        unlock();
+        return NULL;
+    }
+    if(usedlist) {
+        member = static_cast<Stack::member *>(usedlist);
         obj = member->object;
         usedlist = member->getNext();
         member->enlist(&freelist);
@@ -634,7 +682,7 @@ ObjectProtocol *stack::pull(timeout_t timeout)
     return obj;
 }
 
-bool stack::push(ObjectProtocol *object, timeout_t timeout)
+bool Stack::push(ObjectProtocol *object, timeout_t timeout)
 {
     assert(object != NULL);
 
@@ -643,7 +691,7 @@ bool stack::push(ObjectProtocol *object, timeout_t timeout)
     LinkedObject *mem;
 
     if(timeout && timeout != Timer::inf)
-        gettimeout(timeout, &ts);
+        set(&ts, timeout);
 
     lock();
     while(rtn && limit && used == limit) {
@@ -679,13 +727,13 @@ bool stack::push(ObjectProtocol *object, timeout_t timeout)
     return true;
 }
 
-size_t stack::getCount(void)
+size_t Stack::count(void)
 {
-    size_t count;
+    size_t scount;
     lock();
-    count = used;
+    scount = used;
     unlock();
-    return count;
+    return scount;
 }
 
 
