@@ -37,8 +37,8 @@ extern "C" {
     {
         assert(o1 != NULL);
         assert(o2 != NULL);
-        const stringpager::member * const *n1 = static_cast<const stringpager::member * const*>(o1);
-        const stringpager::member * const *n2 = static_cast<const stringpager::member * const*>(o2);
+        const StringPager::member * const *n1 = static_cast<const StringPager::member * const*>(o1);
+        const StringPager::member * const *n2 = static_cast<const StringPager::member * const*>(o2);
         return String::collate((*n1)->get(), (*n2)->get());
     }
 }
@@ -87,7 +87,7 @@ memalloc::~memalloc()
     memalloc::purge();
 }
 
-unsigned memalloc::utilization(void)
+unsigned memalloc::utilization(void) const
 {
     unsigned long used = 0, alloc = 0;
     page_t *mp = page;
@@ -117,6 +117,11 @@ void memalloc::purge(void)
     count = 0;
 }
 
+void memalloc::fault(void) const
+{
+    cpr_runtime_error("mempager exhausted");
+}
+
 memalloc::page_t *memalloc::pager(void)
 {
     page_t *npage = NULL;
@@ -124,7 +129,8 @@ memalloc::page_t *memalloc::pager(void)
     void *addr;
 #endif
 
-    crit(!limit || count < limit, "mempager limit reached");
+    if(limit && count >= limit)
+        fault();
 
 #ifdef  HAVE_POSIX_MEMALIGN
     if(align && !posix_memalign(&addr, align, pagesize)) {
@@ -137,7 +143,8 @@ memalloc::page_t *memalloc::pager(void)
 #ifdef  HAVE_POSIX_MEMALIGN
 use:
 #endif
-    crit(npage != NULL, "mempager alloc failed");
+    if(!npage)
+        fault();
 
     ++count;
     npage->used = sizeof(page_t);
@@ -156,7 +163,10 @@ void *memalloc::_alloc(size_t size)
     caddr_t mem;
     page_t *p = page;
 
-    crit(size <= (pagesize - sizeof(page_t)), "mempager alloc failed");
+    if(size > (pagesize - sizeof(page_t))) {
+        fault();
+        return NULL;
+    }
 
     while(size % sizeof(void *))
         ++size;
@@ -228,19 +238,19 @@ void *mempager::_alloc(size_t size)
     return mem;
 }
 
-objectpager::member::member(LinkedObject **root) :
+ObjectPager::member::member(LinkedObject **root) :
 LinkedObject(root)
 {
     mem = NULL;
 }
 
-objectpager::member::member() :
+ObjectPager::member::member() :
 LinkedObject()
 {
     mem = NULL;
 }
 
-objectpager::objectpager(size_t objsize, size_t size) :
+ObjectPager::ObjectPager(size_t objsize, size_t size) :
 memalloc(size)
 {
     members = 0;
@@ -250,24 +260,20 @@ memalloc(size)
     typesize = objsize;
 }
 
-void *objectpager::get(unsigned index)
+void *ObjectPager::get(unsigned ind) const
 {
-    _lock();
     linked_pointer<member> list = root;
 
-    if(index >= members) {
-        _unlock();
-        return NULL;
-    }
+    if(ind >= members)
+        return invalid();
 
-    while(index--)
+    while(ind--)
         list.next();
 
-    _unlock();
     return list->mem;
 }
 
-void objectpager::clear(void)
+void ObjectPager::clear(void)
 {
     memalloc::purge();
     members = 0;
@@ -276,13 +282,10 @@ void objectpager::clear(void)
     index = NULL;
 }
 
-void *objectpager::pull(void)
+void *ObjectPager::pull(void)
 {
-    _lock();
-    if(!members) {
-        _unlock();
-        return NULL;
-    }
+    if(!members)
+        return invalid();
 
     member *mem = (member *)root;
     void *result = mem->mem;
@@ -292,15 +295,13 @@ void *objectpager::pull(void)
         last = NULL;
     }
     else
-        root = mem->next;
+        root = mem->Next;
     index = NULL;
-    _unlock();
     return result;
 }
 
-void *objectpager::push(void)
+void *ObjectPager::push(void)
 {
-    _lock();
     caddr_t mem = (caddr_t)memalloc::_alloc(sizeof(member));
 
     member *node;
@@ -311,19 +312,15 @@ void *objectpager::push(void)
     ++members;
     node->mem = memalloc::_alloc(typesize);
     index = NULL;
-    _unlock();
     return node->mem;
 }
 
-void *objectpager::pop(void)
+void *ObjectPager::pop(void)
 {
     void *out = NULL;
 
-    _lock();
-    if(!root) {
-        _unlock();
-        return NULL;
-    }
+    if(!root)
+        return invalid();
 
     index = NULL;
 
@@ -331,28 +328,30 @@ void *objectpager::pop(void)
         out = last->mem;
         root = last = NULL;
         members = 0;
-        _unlock();
         return out;
     }
 
     linked_pointer<member> np = root;
     while(is(np)) {
-        if(np->next == last) {
+        if(np->Next == last) {
             out = last->mem;
             last = *np;
-            np->next = NULL;
+            np->Next = NULL;
             --members;
             break;
         }
         np.next();
     }
-    _unlock();
     return out;
 }
 
-void *objectpager::add(void)
+void *ObjectPager::invalid(void) const
+{
+    return NULL;
+}
+
+void *ObjectPager::add(void)
 {
-    _lock();
     caddr_t mem = (caddr_t)memalloc::_alloc(sizeof(member));
     member *node;
 
@@ -365,18 +364,14 @@ void *objectpager::add(void)
         node = new(mem) member(&root);
     last = node;
     node->mem = memalloc::_alloc(typesize);
-    _unlock();
     return node->mem;
 }
 
-void **objectpager::list(void)
+void **ObjectPager::list(void)
 {
-    _lock();
     void **dp = index;
-    if(dp) {
-        _unlock();
+    if(dp)
         return dp;
-    }
 
     unsigned pos = 0;
     index = (void **)memalloc::_alloc(sizeof(void *) * (members + 1));
@@ -387,23 +382,22 @@ void **objectpager::list(void)
     }
     index[pos] = NULL;
     dp = index;
-    _unlock();
     return index;
 }
 
-stringpager::member::member(LinkedObject **root, const char *data) :
+StringPager::member::member(LinkedObject **root, const char *data) :
 LinkedObject(root)
 {
     text = data;
 }
 
-stringpager::member::member(const char *data) :
+StringPager::member::member(const char *data) :
 LinkedObject()
 {
     text = data;
 }
 
-stringpager::stringpager(size_t size) :
+StringPager::StringPager(size_t size) :
 memalloc(size)
 {
     members = 0;
@@ -412,7 +406,7 @@ memalloc(size)
     index = NULL;
 }
 
-stringpager::stringpager(char **list, size_t size) :
+StringPager::StringPager(char **list, size_t size) :
 memalloc(size)
 {
     members = 0;
@@ -421,24 +415,30 @@ memalloc(size)
     add(list);
 }
 
-unsigned stringpager::token(const char *text, const char *list, const char *quote, const char *end)
+bool StringPager::filter(char *buffer, size_t size)
+{
+    add(buffer);
+    return true;
+}
+
+unsigned StringPager::token(const char *text, const char *list, const char *quote, const char *end)
 {
     unsigned count = 0;
     const char *result;
-    char *last = NULL;
+    char *lastp = NULL;
 
     if(!text || !*text)
         return 0;
 
     strdup_t tmp = strdup(text);
-    while(NULL != (result = String::token(tmp, &last, list, quote, end))) {
+    while(NULL != (result = String::token(tmp, &lastp, list, quote, end))) {
         ++count;
         add(result);
     }
     return count;
 }
 
-String stringpager::join(const char *prefix, const char *middle, const char *suffix)
+String StringPager::join(const char *prefix, const char *middle, const char *suffix)
 {
     string_t tmp;
 
@@ -451,9 +451,9 @@ String stringpager::join(const char *prefix, const char *middle, const char *suf
     linked_pointer<member> mp = root;
     while(is(mp)) {
         tmp += mp->text;
-        if(mp->next && middle && *middle)
+        if(mp->Next && middle && *middle)
             tmp += middle;
-        else if(mp->next == NULL && suffix && *suffix)
+        else if(mp->Next == NULL && suffix && *suffix)
             tmp += suffix;
         mp.next();
     }
@@ -461,7 +461,7 @@ String stringpager::join(const char *prefix, const char *middle, const char *suf
     return tmp;
 }
 
-unsigned stringpager::split(const char *text, const char *string, unsigned flags)
+unsigned StringPager::split(const char *text, const char *string, unsigned flags)
 {
     strdup_t tmp = String::dup(string);
     char *match = tmp;
@@ -507,13 +507,13 @@ unsigned stringpager::split(const char *text, const char *string, unsigned flags
     return count;
 }
 
-void stringpager::set(unsigned index, const char *text)
+void StringPager::set(unsigned ind, const char *text)
 {
     linked_pointer<member> list = root;
 
-    if(index >= members)
+    if(ind >= members)
 
-    while(index--)
+    while(ind--)
         list.next();
 
     size_t size = strlen(text) + 1;
@@ -522,20 +522,25 @@ void stringpager::set(unsigned index, const char *text)
     list->text = str;
 }
 
-const char *stringpager::get(unsigned index)
+const char *StringPager::invalid(void) const
+{
+    return NULL;
+}
+
+const char *StringPager::get(unsigned ind) const
 {
     linked_pointer<member> list = root;
 
-    if(index >= members)
-        return NULL;
+    if(ind >= members)
+        return invalid();
 
-    while(index--)
+    while(ind--)
         list.next();
 
     return list->get();
 }
 
-void stringpager::clear(void)
+void StringPager::clear(void)
 {
     memalloc::purge();
     members = 0;
@@ -544,10 +549,10 @@ void stringpager::clear(void)
     index = NULL;
 }
 
-const char *stringpager::pull(void)
+const char *StringPager::pull(void)
 {
     if(!members)
-        return NULL;
+        return invalid();
 
 
     member *mem = (member *)root;
@@ -558,12 +563,12 @@ const char *stringpager::pull(void)
         last = NULL;
     }
     else
-        root = mem->next;
+        root = mem->Next;
     index = NULL;
     return result;
 }
 
-void stringpager::push(const char *text)
+void StringPager::push(const char *text)
 {
     if(!text)
         text = "";
@@ -582,12 +587,12 @@ void stringpager::push(const char *text)
     index = NULL;
 }
 
-const char *stringpager::pop(void)
+const char *StringPager::pop(void)
 {
     const char *out = NULL;
 
     if(!root)
-        return NULL;
+        return invalid();
 
     index = NULL;
 
@@ -600,10 +605,10 @@ const char *stringpager::pop(void)
 
     linked_pointer<member> np = root;
     while(is(np)) {
-        if(np->next == last) {
+        if(np->Next == last) {
             out = last->text;
             last = *np;
-            np->next = NULL;
+            np->Next = NULL;
             --members;
             break;
         }
@@ -612,7 +617,7 @@ const char *stringpager::pop(void)
     return out;
 }
 
-void stringpager::add(const char *text)
+void StringPager::add(const char *text)
 {
     if(!text)
         text = "";
@@ -634,37 +639,37 @@ void stringpager::add(const char *text)
     last = node;
 }
 
-void stringpager::set(char **list)
+void StringPager::set(char **list)
 {
     clear();
     add(list);
 }
 
-void stringpager::push(char **list)
+void StringPager::push(char **list)
 {
     const char *cp;
-    unsigned index = 0;
+    unsigned ind = 0;
 
     if(!list)
         return;
 
-    while(NULL != (cp = list[index++]))
+    while(NULL != (cp = list[ind++]))
         push(cp);
 }
 
-void stringpager::add(char **list)
+void StringPager::add(char **list)
 {
     const char *cp;
-    unsigned index = 0;
+    unsigned ind = 0;
 
     if(!list)
         return;
 
-    while(NULL != (cp = list[index++]))
+    while(NULL != (cp = list[ind++]))
         add(cp);
 }
 
-void stringpager::sort(void)
+void StringPager::sort(void)
 {
     if(!members)
         return;
@@ -687,7 +692,7 @@ void stringpager::sort(void)
     index = NULL;
 }
 
-char **stringpager::list(void)
+char **StringPager::list(void)
 {
     if(index)
         return index;
@@ -704,23 +709,23 @@ char **stringpager::list(void)
 }
 
 DirPager::DirPager() :
-stringpager()
+StringPager()
 {
     dir = NULL;
 }
 
 DirPager::DirPager(const char *path) :
-stringpager()
+StringPager()
 {
     dir = NULL;
     load(path);
 }
 
-bool DirPager::filter(const char *fname)
+bool DirPager::filter(char *fname, size_t size)
 {
     if(*fname != '.')
-        return true;
-    return false;
+        add(fname);
+    return true;
 }
 
 void DirPager::operator=(const char *path)
@@ -732,20 +737,20 @@ void DirPager::operator=(const char *path)
 
 bool DirPager::load(const char *path)
 {
-    fsys_t ds;
+    dir_t ds;
     char buffer[128];
 
-    if(!fsys::isdir(path))
+    if(!fsys::is_dir(path))
         return false;
 
     dir = dup(path);
-    ds.open(path, fsys::ACCESS_DIRECTORY);
+    ds.open(path);
     if(!ds)
         return false;
 
     while(ds.read(buffer, sizeof(buffer)) > 0) {
-        if(filter(buffer))
-            add(buffer);
+        if(!filter(buffer, sizeof(buffer)))
+            break;
     }
 
     ds.close();
@@ -786,6 +791,12 @@ LinkedObject(NULL), CountedObject()
 {
 }
 
+void PagerObject::reset(void)
+{
+    CountedObject::reset();
+    LinkedObject::Next = NULL;
+}
+
 void PagerObject::dealloc(void)
 {
     pager->put(this);
@@ -824,19 +835,20 @@ PagerObject *PagerPool::get(size_t size)
     pthread_mutex_lock(&mutex);
     ptr = static_cast<PagerObject *>(freelist);
     if(ptr)
-        freelist = ptr->next;
+        freelist = ptr->Next;
 
     pthread_mutex_unlock(&mutex);
 
     if(!ptr)
         ptr = new((caddr_t)(_alloc(size))) PagerObject;
-    memset(ptr, 0, size);
+    else
+        ptr->reset();
     ptr->pager = this;
     return ptr;
 }
 
-keyassoc::keydata::keydata(keyassoc *assoc, char *kid, unsigned max, unsigned bufsize) :
-NamedObject(assoc->root, kid, max)
+keyassoc::keydata::keydata(keyassoc *assoc, const char *kid, unsigned max, unsigned bufsize) :
+NamedObject(assoc->root, strdup(kid), max)
 {
     assert(assoc != NULL);
     assert(kid != NULL && *kid != 0);
@@ -844,7 +856,7 @@ NamedObject(assoc->root, kid, max)
 
     String::set(text, bufsize, kid);
     data = NULL;
-    id = text;
+    Id = text;
 }
 
 keyassoc::keyassoc(unsigned pathmax, size_t strmax, size_t ps) :
@@ -856,7 +868,7 @@ mempager(ps)
 
     paths = pathmax;
     keysize = strmax;
-    count = 0;
+    keycount = 0;
 
     root = (NamedObject **)_alloc(sizeof(NamedObject *) * pathmax);
     memset(root, 0, sizeof(NamedObject *) * pathmax);
@@ -918,12 +930,12 @@ void *keyassoc::remove(const char *id)
     obj = static_cast<LinkedObject*>(kd);
     obj->delist((LinkedObject**)(&root[path]));
     obj->enlist(&list[size / 8]);
-    --count;
+    --keycount;
     _unlock();
     return data;
 }
 
-void *keyassoc::allocate(char *id, size_t dsize)
+void *keyassoc::allocate(const char *id, size_t dsize)
 {
     assert(id != NULL && *id != 0);
     assert(dsize != 0);
@@ -957,12 +969,12 @@ void *keyassoc::allocate(char *id, size_t dsize)
         dp = ((keydata *)(ptr))->data;
     kd = new(ptr) keydata(this, id, paths, 8 + size * 8);
     kd->data = dp;
-    ++count;
+    ++keycount;
     _unlock();
     return dp;
 }
 
-bool keyassoc::create(char *id, void *data)
+bool keyassoc::create(const char *id, void *data)
 {
     assert(id != NULL && *id != 0);
     assert(data != NULL);
@@ -991,12 +1003,12 @@ bool keyassoc::create(char *id, void *data)
         ptr = (caddr_t)memalloc::_alloc(sizeof(keydata) + size * 8);
     kd = new(ptr) keydata(this, id, paths, 8 + size * 8);
     kd->data = data;
-    ++count;
+    ++keycount;
     _unlock();
     return true;
 }
 
-bool keyassoc::assign(char *id, void *data)
+bool keyassoc::assign(const char *id, void *data)
 {
     assert(id != NULL && *id != 0);
     assert(data != NULL);
@@ -1021,26 +1033,29 @@ bool keyassoc::assign(char *id, void *data)
         if(ptr == NULL)
             ptr = (caddr_t)memalloc::_alloc(sizeof(keydata) + size * 8);
         kd = new(ptr) keydata(this, id, paths, 8 + size * 8);
-        ++count;
+        ++keycount;
     }
     kd->data = data;
     _unlock();
     return true;
 }
 
-chartext::chartext()
+chartext::chartext() :
+CharacterProtocol()
 {
     pos = NULL;
     max = 0;
 }
 
-chartext::chartext(char *buf)
+chartext::chartext(char *buf) :
+CharacterProtocol()
 {
     pos = buf;
     max = 0;
 }
 
-chartext::chartext(char *buf, size_t size)
+chartext::chartext(char *buf, size_t size) :
+CharacterProtocol()
 {
     pos = buf;
     max = size;
@@ -1063,6 +1078,12 @@ int chartext::_putch(int code)
     if(!pos || !max)
         return EOF;
 
+    if(code == 0) {
+        *(pos++) = 0;
+        max = 0;
+        return EOF;
+    }
+
     *(pos++) = code;
     *pos = 0;
     --max;
@@ -1070,11 +1091,12 @@ int chartext::_putch(int code)
 }
 
 bufpager::bufpager(size_t ps) :
-memalloc(ps)
+memalloc(ps), CharacterProtocol()
 {
     first = last = current = freelist = NULL;
     ccount = 0;
     cpos = 0;
+    eom = false;
 }
 
 void bufpager::set(const char *text)
@@ -1085,7 +1107,8 @@ void bufpager::set(const char *text)
 
 void bufpager::put(const char *text, size_t iosize)
 {
-    _lock();
+    if(eom)
+        return;
 
     while(text && (iosize--)) {
         if(!last || last->used == last->size) {
@@ -1098,7 +1121,6 @@ void bufpager::put(const char *text, size_t iosize)
             else {
                 next = (cpage_t *)memalloc::_alloc(sizeof(cpage_t));
                 if(!next) {
-                    _unlock();
                     return;
                 }
 
@@ -1114,10 +1136,8 @@ void bufpager::put(const char *text, size_t iosize)
                 if(!p)
                     p = pager();
 
-                if(!p) {
-                    _unlock();
+                if(!p)
                     return;
-                }
 
                 next->text = ((char *)(p)) + p->used;
                 next->used = 0;
@@ -1136,17 +1156,13 @@ void bufpager::put(const char *text, size_t iosize)
         ++ccount;
         last->text[last->used++] = *(text++);
     }
-    _unlock();
 }
 
 char *bufpager::copy(size_t *iosize)
 {
     *iosize = 0;
-    _lock();
-    if(!current || (current->next == NULL && cpos >= current->used)) {
-        _unlock();
+    if(!current || (current->next == NULL && cpos >= current->used))
         return NULL;
-    }
 
     if(cpos >= current->used) {
         current = current->next;
@@ -1162,8 +1178,10 @@ char *bufpager::copy(size_t *iosize)
 
 char *bufpager::request(size_t *iosize)
 {
+    if(eom)
+        return NULL;
+
     *iosize = 0;
-    _lock();
     if(!last || last->used >= last->size) {
         cpage_t *next;
         if(freelist) {
@@ -1173,7 +1191,7 @@ char *bufpager::request(size_t *iosize)
         else {
             next = (cpage_t *)memalloc::_alloc(sizeof(cpage_t));
             if(!next) {
-                _unlock();
+                eom = true;
                 return NULL;
             }
 
@@ -1190,9 +1208,10 @@ char *bufpager::request(size_t *iosize)
                 p = pager();
 
             if(!p) {
-                _unlock();
+                eom = true;
                 return NULL;
             }
+
             next->text = ((char *)(p)) + p->used;
             next->used = 0;
             next->size = size;
@@ -1210,24 +1229,15 @@ char *bufpager::request(size_t *iosize)
     return last->text + last->used;
 }
 
-void bufpager::commit(size_t iosize)
+void bufpager::update(size_t iosize)
 {
     last->used += iosize;
-    _unlock();
-}
-
-void bufpager::release(void)
-{
-    _unlock();
 }
 
 size_t bufpager::get(char *text, size_t iosize)
 {
-    _lock();
-    if(!ccount) {
-        _unlock();
+    if(!ccount)
         return 0;
-    }
 
     unsigned long index = 0;
 
@@ -1242,13 +1252,13 @@ size_t bufpager::get(char *text, size_t iosize)
     }
     if(index < iosize)
         text[index] = 0;
-    _unlock();
     return index;
 }
 
 void bufpager::add(const char *text)
 {
-    _lock();
+    if(eom)
+        return;
 
     while(text && *text) {
         if(!last || last->used == last->size) {
@@ -1261,7 +1271,7 @@ void bufpager::add(const char *text)
             else {
                 next = (cpage_t *)memalloc::_alloc(sizeof(cpage_t));
                 if(!next) {
-                    _unlock();
+                    eom = true;
                     return;
                 }
 
@@ -1278,7 +1288,7 @@ void bufpager::add(const char *text)
                     p = pager();
 
                 if(!p) {
-                    _unlock();
+                    eom = true;
                     return;
                 }
 
@@ -1299,74 +1309,62 @@ void bufpager::add(const char *text)
         ++ccount;
         last->text[last->used++] = *(text++);
     }
-    _unlock();
 }
 
 char *bufpager::dup(void)
 {
-    _lock();
-    if(!ccount) {
-        _unlock();
+    if(!ccount)
         return NULL;
-    }
 
     char *text = (char *)malloc(ccount + 1l);
-    if(!text) {
-        _unlock();
+    if(!text)
         return NULL;
-    }
 
     unsigned long index = 0, pos = 0;
-    cpage_t *page = first;
+    cpage_t *cpage = first;
 
-    while(index < ccount && page) {
-        if(pos >= page->used) {
-            if(!page->next)
+    while(index < ccount && cpage) {
+        if(pos >= cpage->used) {
+            if(!cpage->next)
                 break;
-            page = page->next;
+            cpage = cpage->next;
             pos = 0l;
         }
-        text[index++] = page->text[pos++];
+        text[index++] = cpage->text[pos++];
     }
     text[index] = 0;
-    _unlock();
     return text;
 }
 
 int bufpager::_getch(void)
 {
-    _lock();
 
     if(!current)
         current = first;
 
-    if(!current) {
-        _unlock();
+    if(!current)
         return EOF;
-    }
 
     if(cpos >= current->used) {
-        if(!current->next) {
-            _unlock();
+        if(!current->next)
             return EOF;
-        }
+
         current = current->next;
         cpos = 0;
     }
 
-    if(cpos >= current->used) {
-        _unlock();
+    if(cpos >= current->used)
         return EOF;
-    }
 
     char ch = current->text[cpos++];
-    _unlock();
     return ch;
 }
 
 int bufpager::_putch(int code)
 {
-    _lock();
+    if(eom)
+        return EOF;
+
     if(!last || last->used == last->size) {
         cpage_t *next;
 
@@ -1377,7 +1375,7 @@ int bufpager::_putch(int code)
         else {
             next = (cpage_t *)memalloc::_alloc(sizeof(cpage_t));
             if(!next) {
-                _unlock();
+                eom = true;
                 return EOF;
             }
 
@@ -1394,7 +1392,7 @@ int bufpager::_putch(int code)
                 p = pager();
 
             if(!p) {
-                _unlock();
+                eom = true;
                 return EOF;
             }
 
@@ -1414,29 +1412,28 @@ int bufpager::_putch(int code)
 
     ++ccount;
     last->text[last->used++] = code;
-    _unlock();
+    if(code == 0) {
+        eom = true;
+        return EOF;
+    }
     return code;
 }
 
 void *bufpager::_alloc(size_t size)
 {
-    _lock();
     void *ptr = memalloc::_alloc(size);
-    _unlock();
     return ptr;
 }
 
 void bufpager::rewind(void)
 {
-    _lock();
     cpos = 0;
     current = first;
-    _unlock();
 }
 
 void bufpager::reset(void)
 {
-    _lock();
+    eom = false;
     cpos = 0;
     ccount = 0;
     current = first;
@@ -1446,14 +1443,14 @@ void bufpager::reset(void)
     }
     freelist = first;
     first = last = current = NULL;
-    _unlock();
 }
 
-charmem::charmem(char *mem, size_t size)
+charmem::charmem(char *memaddr, size_t memsize) :
+CharacterProtocol()
 {
     dynamic = false;
     buffer = NULL;
-    set(mem, size);
+    set(memaddr, memsize);
 }
 
 charmem::charmem(size_t memsize)
@@ -1522,6 +1519,12 @@ int charmem::_putch(int code)
         return EOF;
 
     buffer[out++] = code;
+
+    if(code == 0) {
+        out = size;
+        return EOF;
+    }
+
     buffer[out] = 0;
     return code;
 }
