@@ -545,8 +545,6 @@ static unsigned bitcount(bit_t *bits, unsigned len)
     return count;
 }
 
-const size_t Socket::masksize = sizeof(fd_set);
-
 #ifdef  _MSWINDOWS_
 
 static bool _started = false;
@@ -622,18 +620,18 @@ void Socket::v4mapping(bool enable)
         v6only = 1;
 }
 
-void Socket::family(int query)
+void Socket::query(int querymode)
 {
-    query_family = query;
+    query_family = querymode;
 }
 
 cidr::cidr() :
 LinkedObject()
 {
-    family = AF_UNSPEC;
-    memset(&network, 0, sizeof(network));
-    memset(&netmask, 0, sizeof(netmask));
-    name[0] = 0;
+    Family = AF_UNSPEC;
+    memset(&Network, 0, sizeof(Network));
+    memset(&Netmask, 0, sizeof(Netmask));
+    Name[0] = 0;
 }
 
 cidr::cidr(const char *cp) :
@@ -641,7 +639,7 @@ LinkedObject()
 {
     assert(cp != NULL && *cp != 0);
     set(cp);
-    name[0] = 0;
+    Name[0] = 0;
 }
 
 cidr::cidr(policy **policy, const char *cp) :
@@ -651,7 +649,7 @@ LinkedObject(policy)
     assert(cp != NULL && *cp != 0);
 
     set(cp);
-    name[0] = 0;
+    Name[0] = 0;
 }
 
 cidr::cidr(policy **policy, const char *cp, const char *id) :
@@ -662,45 +660,45 @@ LinkedObject(policy)
     assert(id != NULL && *id != 0);
 
     set(cp);
-    string::set(name, sizeof(name), id);
+    String::set(Name, sizeof(Name), id);
 }
 
 
 cidr::cidr(const cidr &copy) :
 LinkedObject()
 {
-    family = copy.family;
-    memcpy(&network, &copy.network, sizeof(network));
-    memcpy(&netmask, &copy.netmask, sizeof(netmask));
-    memcpy(&name, &copy.name, sizeof(name));
+    Family = copy.Family;
+    memcpy(&Network, &copy.Network, sizeof(Network));
+    memcpy(&Netmask, &copy.Netmask, sizeof(Netmask));
+    memcpy(&Name, &copy.Name, sizeof(Name));
 }
 
-unsigned cidr::getMask(void) const
+unsigned cidr::mask(void) const
 {
-    switch(family)
+    switch(Family)
     {
     case AF_INET:
-        return bitcount((bit_t *)&netmask.ipv4, sizeof(struct in_addr));
+        return bitcount((bit_t *)&Netmask.ipv4, sizeof(struct in_addr));
 #ifdef  AF_INET6
     case AF_INET6:
-        return bitcount((bit_t *)&netmask.ipv6, sizeof(struct in6_addr));
+        return bitcount((bit_t *)&Netmask.ipv6, sizeof(struct in6_addr));
 #endif
     default:
         return 0;
     }
 }
 
-cidr *cidr::find(policy *policy, const struct sockaddr *s)
+const cidr *cidr::find(const policy *policy, const struct sockaddr *s)
 {
     assert(policy != NULL);
     assert(s != NULL);
 
-    cidr *member = NULL;
+    const cidr *member = NULL;
     unsigned top = 0;
 
-    linked_pointer<cidr> p = policy;
+    linked_pointer<const cidr> p = policy;
     while(p) {
-        if(p->isMember(s)) {
+        if(p->is_member(s)) {
             if(p->getMask() > top) {
                 top = p->getMask();
                 member = *p;
@@ -711,17 +709,17 @@ cidr *cidr::find(policy *policy, const struct sockaddr *s)
     return member;
 }
 
-cidr *cidr::container(policy *policy, const struct sockaddr *s)
+const cidr *cidr::container(const policy *policy, const struct sockaddr *s)
 {
     assert(policy != NULL);
     assert(s != NULL);
 
-    cidr *member = NULL;
+    const cidr *member = NULL;
     unsigned top = 128;
 
-    linked_pointer<cidr> p = policy;
+    linked_pointer<const cidr> p = policy;
     while(p) {
-        if(p->isMember(s)) {
+        if(p->is_member(s)) {
             if(p->getMask() < top) {
                 top = p->getMask();
                 member = *p;
@@ -733,28 +731,28 @@ cidr *cidr::container(policy *policy, const struct sockaddr *s)
 }
 
 
-bool cidr::isMember(const struct sockaddr *s) const
+bool cidr::is_member(const struct sockaddr *s) const
 {
     assert(s != NULL);
 
     inethostaddr_t host;
     struct sockaddr_internet *addr = (struct sockaddr_internet *)s;
 
-    if(addr->address.sa_family != family)
+    if(addr->address.sa_family != Family)
         return false;
 
-    switch(family) {
+    switch(Family) {
     case AF_INET:
         memcpy(&host.ipv4, &addr->ipv4.sin_addr, sizeof(host.ipv4));
-        bitmask((bit_t *)&host.ipv4, (bit_t *)&netmask, sizeof(host.ipv4));
-        if(!memcmp(&host.ipv4, &network.ipv4, sizeof(host.ipv4)))
+        bitmask((bit_t *)&host.ipv4, (bit_t *)&Netmask, sizeof(host.ipv4));
+        if(!memcmp(&host.ipv4, &Network.ipv4, sizeof(host.ipv4)))
             return true;
         return false;
 #ifdef  AF_INET6
     case AF_INET6:
         memcpy(&host.ipv6, &addr->ipv6.sin6_addr, sizeof(host.ipv6));
-        bitmask((bit_t *)&host.ipv6, (bit_t *)&netmask, sizeof(host.ipv6));
-        if(!memcmp(&host.ipv6, &network.ipv6, sizeof(host.ipv6)))
+        bitmask((bit_t *)&host.ipv6, (bit_t *)&Netmask, sizeof(host.ipv6));
+        if(!memcmp(&host.ipv6, &Network.ipv6, sizeof(host.ipv6)))
             return true;
         return false;
 #endif
@@ -763,19 +761,19 @@ bool cidr::isMember(const struct sockaddr *s) const
     }
 }
 
-inethostaddr_t cidr::getBroadcast(void) const
+inethostaddr_t cidr::broadcast(void) const
 {
     inethostaddr_t bcast;
 
-    switch(family) {
+    switch(Family) {
     case AF_INET:
-        memcpy(&bcast.ipv4, &network.ipv4, sizeof(network.ipv4));
-        bitimask((bit_t *)&bcast.ipv4, (bit_t *)&netmask.ipv4, sizeof(bcast.ipv4));
+        memcpy(&bcast.ipv4, &Network.ipv4, sizeof(Network.ipv4));
+        bitimask((bit_t *)&bcast.ipv4, (bit_t *)&Netmask.ipv4, sizeof(bcast.ipv4));
         return bcast;
 #ifdef  AF_INET6
     case AF_INET6:
-        memcpy(&bcast.ipv6, &network.ipv6, sizeof(network.ipv6));
-        bitimask((bit_t *)&bcast.ipv6, (bit_t *)&netmask.ipv6, sizeof(bcast.ipv6));
+        memcpy(&bcast.ipv6, &Network.ipv6, sizeof(Network.ipv6));
+        bitimask((bit_t *)&bcast.ipv6, (bit_t *)&Netmask.ipv6, sizeof(bcast.ipv6));
         return bcast;
 #endif
     default:
@@ -784,7 +782,7 @@ inethostaddr_t cidr::getBroadcast(void) const
     }
 }
 
-unsigned cidr::getMask(const char *cp) const
+unsigned cidr::mask(const char *cp) const
 {
     assert(cp != NULL && *cp != 0);
 
@@ -795,7 +793,7 @@ unsigned cidr::getMask(const char *cp) const
     unsigned char dots[4];
     uint32_t mask;
 
-    switch(family) {
+    switch(Family) {
 #ifdef  AF_INET6
     case AF_INET6:
         if(sp)
@@ -873,16 +871,16 @@ void cidr::set(const char *cp)
 
 #ifdef  AF_INET6
     if(strchr(cp, ':'))
-        family = AF_INET6;
+        Family = AF_INET6;
     else
 #endif
-        family = AF_INET;
+        Family = AF_INET;
 
-    switch(family) {
+    switch(Family) {
     case AF_INET:
-        memset(&netmask.ipv4, 0, sizeof(netmask.ipv4));
-        bitset((bit_t *)&netmask.ipv4, getMask(cp));
-        string::set(cbuf, sizeof(cbuf), cp);
+        memset(&Netmask.ipv4, 0, sizeof(Netmask.ipv4));
+        bitset((bit_t *)&Netmask.ipv4, mask(cp));
+        String::set(cbuf, sizeof(cbuf), cp);
         ep = (char *)strchr(cbuf, '/');
         if(ep)
             *ep = 0;
@@ -894,20 +892,20 @@ void cidr::set(const char *cp)
         }
 
         while(dots++ < 3)
-            string::add(cbuf, sizeof(cbuf), ".0");
+            String::add(cbuf, sizeof(cbuf), ".0");
 
 #ifdef  _MSWINDOWS_
-        memcpy(&network.ipv4, &addr, sizeof(network.ipv4));
+        memcpy(&Network.ipv4, &addr, sizeof(Network.ipv4));
 #else
-        inet_aton(cbuf, &network.ipv4);
+        inet_aton(cbuf, &Network.ipv4);
 #endif
-        bitmask((bit_t *)&network.ipv4, (bit_t *)&netmask.ipv4, sizeof(network.ipv4));
+        bitmask((bit_t *)&Network.ipv4, (bit_t *)&Netmask.ipv4, sizeof(Network.ipv4));
         break;
 #ifdef  AF_INET6
     case AF_INET6:
-        memset(&netmask.ipv6, 0, sizeof(netmask));
-        bitset((bit_t *)&netmask.ipv6, getMask(cp));
-        string::set(cbuf, sizeof(cbuf), cp);
+        memset(&Netmask.ipv6, 0, sizeof(Netmask));
+        bitset((bit_t *)&Netmask.ipv6, mask(cp));
+        String::set(cbuf, sizeof(cbuf), cp);
         ep = (char *)strchr(cp, '/');
         if(ep)
             *ep = 0;
@@ -916,11 +914,11 @@ void cidr::set(const char *cp)
         slen = sizeof(saddr);
         paddr = (struct sockaddr_in6 *)&saddr;
         WSAStringToAddress((LPSTR)cbuf, AF_INET6, NULL, &saddr, &slen);
-        network.ipv6 = paddr->sin6_addr;
+        Network.ipv6 = paddr->sin6_addr;
 #else
-        inet_pton(AF_INET6, cbuf, &network.ipv6);
+        inet_pton(AF_INET6, cbuf, &Network.ipv6);
 #endif
-        bitmask((bit_t *)&network.ipv6, (bit_t *)&netmask.ipv6, sizeof(network.ipv6));
+        bitmask((bit_t *)&Network.ipv6, (bit_t *)&Netmask.ipv6, sizeof(Network.ipv6));
 #endif
     default:
         break;
@@ -1002,7 +1000,7 @@ void Socket::release(struct addrinfo *list)
         freeaddrinfo(list);
 }
 
-struct ::addrinfo *Socket::getaddress(const char *hp, const char *svc, int type, int protocol)
+struct ::addrinfo *Socket::query(const char *hp, const char *svc, int type, int protocol)
 {
     assert(hp != NULL && *hp != 0);
 
@@ -1044,7 +1042,7 @@ struct ::addrinfo *Socket::getaddress(const char *hp, const char *svc, int type,
         svc = cp;
     }
 
-    if(isNumeric(host)) {
+    if(is_numeric(host)) {
         hint.ai_flags |= AI_NUMERICHOST;
 
         if(strchr(host, ':')) {
@@ -1085,10 +1083,10 @@ void Socket::address::set(const char *host, unsigned port)
 
     if(port) {
         snprintf(buf, sizeof(buf), "%u", port);
-        list = Socket::getaddress(host, buf);
+        list = Socket::query(host, buf);
     }
     else
-        list = Socket::getaddress(host, NULL);
+        list = Socket::query(host, NULL);
 }
 
 void Socket::address::set(int family, const char *a, int type, int protocol)
@@ -1148,7 +1146,7 @@ proc:
     getaddrinfo(host, svc, &hint, &list);
 }
 
-struct sockaddr *Socket::address::getAddr(void) const
+struct sockaddr *Socket::address::get(void) const
 {
     if(!list)
         return NULL;
@@ -1156,7 +1154,7 @@ struct sockaddr *Socket::address::getAddr(void) const
     return list->ai_addr;
 }
 
-int Socket::address::getfamily(void) const
+int Socket::address::family(void) const
 {
     struct sockaddr *ap;
     if(!list)
@@ -1251,9 +1249,9 @@ bool Socket::address::insert(struct sockaddr *addr)
     }
 
     node = (struct addrinfo *)malloc(sizeof(struct addrinfo));
-    memset(node, 0, sizeof(node));
+    memset(node, 0, sizeof(struct addrinfo));
     node->ai_family = addr->sa_family;
-    node->ai_addrlen = getlen(addr);
+    node->ai_addrlen = len(addr);
     node->ai_next = list;
     node->ai_addr = (struct sockaddr *)malloc(node->ai_addrlen);
     memcpy(node->ai_addr, addr, node->ai_addrlen);
@@ -1305,12 +1303,12 @@ struct sockaddr *Socket::address::dup(struct sockaddr *addr)
     if(!addr)
         return NULL;
 
-    size_t len = getlen(addr);
-    if(!len)
+    size_t slen = len(addr);
+    if(!slen)
         return NULL;
 
-    node = (struct sockaddr *)malloc(len);
-    memcpy(node, addr, len);
+    node = (struct sockaddr *)malloc(slen);
+    memcpy(node, addr, slen);
     return node;
 }
 
@@ -1321,8 +1319,8 @@ void Socket::address::add(struct sockaddr *addr)
     char buffer[80];
     char svc[8];
 
-    Socket::getaddress(addr, buffer, sizeof(buffer));
-    snprintf(svc, sizeof(svc), "%d", Socket::getservice(addr));
+    Socket::query(addr, buffer, sizeof(buffer));
+    snprintf(svc, sizeof(svc), "%d", Socket::service(addr));
     add(buffer, svc, addr->sa_family);
 }
 
@@ -1339,7 +1337,7 @@ void Socket::address::add(const char *host, const char *svc, int socktype)
 
     struct addrinfo *join = NULL, *last = NULL;
 
-    join = Socket::getaddress(host, svc, socktype);
+    join = Socket::query(host, svc, socktype);
     if(!join)
         return;
 
@@ -1353,7 +1351,7 @@ void Socket::address::add(const char *host, const char *svc, int socktype)
     last->ai_next = join;
 }
 
-struct sockaddr *Socket::address::find(struct sockaddr *addr) const
+struct sockaddr *Socket::address::find(const struct sockaddr *addr) const
 {
     assert(addr != NULL);
 
@@ -1441,7 +1439,7 @@ Socket::Socket(const char *iface, const char *port, int family, int type, int pr
     ioerr = 0;
 }
 
-socket_t Socket::create(Socket::address &address)
+socket_t Socket::create(const Socket::address &address)
 {
     socket_t so;
     struct addrinfo *res = *address;
@@ -1724,16 +1722,16 @@ size_t Socket::readfrom(void *data, size_t len, struct sockaddr_storage *from)
     return (size_t)result;
 }
 
-size_t Socket::writeto(const void *data, size_t len, struct sockaddr *dest)
+size_t Socket::writeto(const void *data, size_t dlen, const struct sockaddr *dest)
 {
     assert(data != NULL);
     assert(len > 0);
 
     socklen_t slen = 0;
     if(dest)
-        slen = getlen(dest);
+        slen = len(dest);
 
-    ssize_t result = _sendto_(so, (caddr_t)data, len, MSG_NOSIGNAL, dest, slen);
+    ssize_t result = _sendto_(so, (caddr_t)data, dlen, MSG_NOSIGNAL, dest, slen);
     if(result < 0) {
         ioerr = Socket::error();
         return 0;
@@ -1741,16 +1739,16 @@ size_t Socket::writeto(const void *data, size_t len, struct sockaddr *dest)
     return (size_t)result;
 }
 
-ssize_t Socket::sendto(socket_t so, const void *data, size_t len, int flags, struct sockaddr *dest)
+ssize_t Socket::sendto(socket_t so, const void *data, size_t dlen, int flags, const struct sockaddr *dest)
 {
     assert(data != NULL);
     assert(len > 0);
 
     socklen_t slen = 0;
     if(dest)
-        slen = getlen(dest);
+        slen = len(dest);
 
-    return _sendto_(so, (caddr_t)data, len, MSG_NOSIGNAL | flags, dest, slen);
+    return _sendto_(so, (caddr_t)data, dlen, MSG_NOSIGNAL | flags, dest, slen);
 }
 
 size_t Socket::writes(const char *str)
@@ -1779,7 +1777,7 @@ size_t Socket::readline(char *data, size_t max)
     return (size_t)result;
 }
 
-size_t Socket::readline(string& s)
+size_t Socket::readline(String& s)
 {
     if(!s.c_mem())
         return 0;
@@ -2066,7 +2064,7 @@ int Socket::multicast(socket_t so, unsigned ttl)
     }
 }
 
-int Socket::join(struct addrinfo *addr)
+int Socket::join(const struct addrinfo *addr)
 {
     int rtn = Socket::join(so, addr);
     if(rtn)
@@ -2074,7 +2072,7 @@ int Socket::join(struct addrinfo *addr)
     return rtn;
 }
 
-int Socket::drop(struct addrinfo *addr)
+int Socket::drop(const struct addrinfo *addr)
 {
     int rtn = Socket::drop(so, addr);
     if(rtn)
@@ -2154,14 +2152,14 @@ int Socket::disconnect(socket_t so)
     return err;
 }
 
-int Socket::join(socket_t so, struct addrinfo *node)
+int Socket::join(socket_t so, const struct addrinfo *node)
 {
     assert(node != NULL);
 
     struct multicast_internet mcast;
     struct sockaddr_internet addr;
     socklen_t len = sizeof(addr);
-    struct sockaddr_internet *target;
+    const struct sockaddr_internet *target;
     int family;
     int rtn = 0;
 
@@ -2170,7 +2168,7 @@ int Socket::join(socket_t so, struct addrinfo *node)
 
     _getsockname_(so, (struct sockaddr *)&addr, &len);
     while(!rtn && node && node->ai_addr) {
-        target = (struct sockaddr_internet *)node->ai_addr;
+        target = (const struct sockaddr_internet *)node->ai_addr;
         family = node->ai_family;
         node = node->ai_next;
         if(family != addr.address.sa_family)
@@ -2202,14 +2200,14 @@ int Socket::join(socket_t so, struct addrinfo *node)
     return rtn;
 }
 
-int Socket::drop(socket_t so, struct addrinfo *node)
+int Socket::drop(socket_t so, const struct addrinfo *node)
 {
     assert(node != NULL);
 
     struct multicast_internet mcast;
     struct sockaddr_internet addr;
     socklen_t len = sizeof(addr);
-    struct sockaddr_internet *target;
+    const struct sockaddr_internet *target;
     int family;
     int rtn = 0;
 
@@ -2218,7 +2216,7 @@ int Socket::drop(socket_t so, struct addrinfo *node)
 
     _getsockname_(so, (struct sockaddr *)&addr, &len);
     while(!rtn && node && node->ai_addr) {
-        target = (struct sockaddr_internet *)node->ai_addr;
+        target = (const struct sockaddr_internet *)node->ai_addr;
         family = node->ai_family;
         node = node->ai_next;
 
@@ -2252,7 +2250,7 @@ int Socket::drop(socket_t so, struct addrinfo *node)
     return rtn;
 }
 
-socket_t Socket::create(struct addrinfo *node, int stype, int sprotocol)
+socket_t Socket::create(const struct addrinfo *node, int stype, int sprotocol)
 {
     assert(node != NULL);
 
@@ -2313,7 +2311,7 @@ int Socket::connectto(socket_t so, struct addrinfo *node)
     if(so == INVALID_SOCKET)
         return EBADF;
 
-    socket_family = getfamily(so);
+    socket_family = family(so);
 
     while(node) {
         if(node->ai_family == socket_family) {
@@ -2397,14 +2395,14 @@ int Socket::recvsize(socket_t so, unsigned size)
 #endif
 }
 
-bool Socket::isConnected(void) const
+bool Socket::connected(void) const
 {
     char buf;
 
     if(so == INVALID_SOCKET)
         return false;
 
-    if(!waitPending())
+    if(!wait())
         return true;
 
     if(_recv_(so, &buf, 1, MSG_DONTWAIT | MSG_PEEK) < 1)
@@ -2413,9 +2411,9 @@ bool Socket::isConnected(void) const
     return true;
 }
 
-bool Socket::isPending(unsigned qio) const
+bool Socket::is_pending(unsigned qio) const
 {
-    if(getPending() >= qio)
+    if(pending() >= qio)
         return true;
 
     return false;
@@ -2455,7 +2453,7 @@ socket_t Socket::acceptfrom(socket_t so, struct sockaddr_storage *addr)
         return _accept_(so, NULL, NULL);
 }
 
-bool Socket::waitPending(timeout_t timeout) const
+bool Socket::wait(timeout_t timeout) const
 {
     return wait(so, timeout);
 }
@@ -2615,7 +2613,7 @@ ListenSocket(address, service, backlog)
 #undef  AF_UNIX
 #endif
 
-struct ::addrinfo *Socket::gethint(socket_t so, struct addrinfo *hint)
+struct ::addrinfo *Socket::hinting(socket_t so, struct addrinfo *hint)
 {
     assert(hint != NULL);
 
@@ -2636,7 +2634,7 @@ struct ::addrinfo *Socket::gethint(socket_t so, struct addrinfo *hint)
     return hint;
 }
 
-int Socket::gettype(socket_t so)
+int Socket::type(socket_t so)
 {
     int sotype;
     socklen_t slen = sizeof(sotype);
@@ -2645,7 +2643,7 @@ int Socket::gettype(socket_t so)
     return sotype;
 }
 
-bool Socket::setccid(socket_t so, uint8_t ccid)
+bool Socket::ccid(socket_t so, uint8_t ccid)
 {
     uint8_t ccids[4];
     socklen_t len = sizeof(ccids);
@@ -2677,7 +2675,7 @@ unsigned Socket::segsize(socket_t so, unsigned size)
     socklen_t alen = sizeof(size);
 #endif
 
-    switch(gettype(so)) {
+    switch(type(so)) {
     case SOCK_STREAM:
 #ifdef  TCP_MAXSEG
         if(size)
@@ -2699,7 +2697,7 @@ unsigned Socket::segsize(socket_t so, unsigned size)
     return size;
 }
 
-char *Socket::gethostname(struct sockaddr *sa, char *buf, size_t max)
+char *Socket::hostname(const struct sockaddr *sa, char *buf, size_t max)
 {
     assert(sa != NULL);
     assert(buf != NULL);
@@ -2708,7 +2706,7 @@ char *Socket::gethostname(struct sockaddr *sa, char *buf, size_t max)
     socklen_t sl;
 
 #ifdef  AF_UNIX
-    struct sockaddr_un *un = (struct sockaddr_un *)sa;
+    const struct sockaddr_un *un = (const struct sockaddr_un *)sa;
 #endif
 
     switch(sa->sa_family) {
@@ -2740,7 +2738,7 @@ char *Socket::gethostname(struct sockaddr *sa, char *buf, size_t max)
     return buf;
 }
 
-socklen_t Socket::getaddr(socket_t so, struct sockaddr_storage *sa, const char *host, const char *svc)
+socklen_t Socket::query(socket_t so, struct sockaddr_storage *sa, const char *host, const char *svc)
 {
     assert(sa != NULL);
     assert(host != NULL && *host != 0);
@@ -2754,7 +2752,7 @@ socklen_t Socket::getaddr(socket_t so, struct sockaddr_storage *sa, const char *
         return unixaddr((struct sockaddr_un *)sa, host);
 #endif
 
-    if(!gethint(so, &hint) || !svc)
+    if(!hinting(so, &hint) || !svc)
         return 0;
 
     if(getaddrinfo(host, svc, &hint, &res) || !res)
@@ -2769,16 +2767,16 @@ exit:
     return len;
 }
 
-int Socket::bindto(socket_t so, struct sockaddr *iface)
+int Socket::bindto(socket_t so, const struct sockaddr *iface)
 {
-    if(!_bind_(so, iface, getlen(iface)))
+    if(!_bind_(so, iface, len(iface)))
         return 0;
     return Socket::error();
 }
 
-int Socket::listento(socket_t so, struct sockaddr *iface, int backlog)
+int Socket::listento(socket_t so, const struct sockaddr *iface, int backlog)
 {
-    if(_bind_(so, iface, getlen(iface)))
+    if(_bind_(so, iface, len(iface)))
         return Socket::error();
     if(_listen_(so, backlog))
         return Socket::error();
@@ -2807,7 +2805,7 @@ int Socket::bindto(socket_t so, const char *host, const char *svc, int protocol)
     };
 #endif
 
-    if(!gethint(so, &hint) || !svc)
+    if(!hinting(so, &hint) || !svc)
         return ENOSYS;
 
     hint.ai_protocol = protocol;
@@ -2844,7 +2842,7 @@ exit:
     return rtn;
 }
 
-unsigned Socket::keyhost(struct sockaddr *addr, unsigned keysize)
+unsigned Socket::keyhost(const struct sockaddr *addr, unsigned keysize)
 {
     assert(addr != NULL);
     assert(keysize > 0);
@@ -2855,12 +2853,12 @@ unsigned Socket::keyhost(struct sockaddr *addr, unsigned keysize)
 switch(addr->sa_family) {
 #ifdef  AF_INET6
     case AF_INET6:
-        cp = (caddr_t)(&((struct sockaddr_in6 *)(addr))->sin6_addr);
+        cp = (caddr_t)(&((const struct sockaddr_in6 *)(addr))->sin6_addr);
         len = 16;
         break;
 #endif
     case AF_INET:
-        cp = (caddr_t)(&((struct sockaddr_in *)(addr))->sin_addr);
+        cp = (caddr_t)(&((const struct sockaddr_in *)(addr))->sin_addr);
         len = 4;
         break;
     default:
@@ -2873,7 +2871,7 @@ switch(addr->sa_family) {
     return key % keysize;
 }
 
-unsigned Socket::keyindex(struct sockaddr *addr, unsigned keysize)
+unsigned Socket::keyindex(const struct sockaddr *addr, unsigned keysize)
 {
     assert(addr != NULL);
     assert(keysize > 0);
@@ -2884,15 +2882,15 @@ unsigned Socket::keyindex(struct sockaddr *addr, unsigned keysize)
 switch(addr->sa_family) {
 #ifdef  AF_INET6
     case AF_INET6:
-        cp = (caddr_t)(&((struct sockaddr_in6 *)(addr))->sin6_addr);
+        cp = (caddr_t)(&((const struct sockaddr_in6 *)(addr))->sin6_addr);
         len = 16;
-        key = getservice(addr);
+        key = service(addr);
         break;
 #endif
     case AF_INET:
-        cp = (caddr_t)(&((struct sockaddr_in *)(addr))->sin_addr);
+        cp = (caddr_t)(&((const struct sockaddr_in *)(addr))->sin_addr);
         len = 4;
-        key = getservice(addr);
+        key = service(addr);
         break;
     default:
         return 0;
@@ -2904,22 +2902,22 @@ switch(addr->sa_family) {
     return key % keysize;
 }
 
-short Socket::getservice(struct sockaddr *addr)
+short Socket::service(const struct sockaddr *addr)
 {
     assert(addr != NULL);
 
     switch(addr->sa_family) {
 #ifdef  AF_INET6
     case AF_INET6:
-        return ntohs(((struct sockaddr_in6 *)(addr))->sin6_port);
+        return ntohs(((const struct sockaddr_in6 *)(addr))->sin6_port);
 #endif
     case AF_INET:
-        return ntohs(((struct sockaddr_in *)(addr))->sin_port);
+        return ntohs(((const struct sockaddr_in *)(addr))->sin_port);
     }
     return 0;
 }
 
-char *Socket::getaddress(struct sockaddr *addr, char *name, socklen_t size)
+char *Socket::query(const struct sockaddr *addr, char *name, socklen_t size)
 {
     assert(addr != NULL);
     assert(name != NULL);
@@ -2935,7 +2933,7 @@ char *Socket::getaddress(struct sockaddr *addr, char *name, socklen_t size)
     switch(addr->sa_family) {
 #ifdef  AF_UNIX
     case AF_UNIX:
-        string::set(name, size, ((struct sockaddr_un *)(addr))->sun_path);
+        String::set(name, size, ((const struct sockaddr_un *)(addr))->sun_path);
         return name;
 #endif
 #ifdef  _MSWINDOWS_
@@ -2957,16 +2955,16 @@ char *Socket::getaddress(struct sockaddr *addr, char *name, socklen_t size)
 #ifdef  HAVE_INET_NTOP
 #ifdef  AF_INET6
     case AF_INET6:
-        inet_ntop(addr->sa_family, &((struct sockaddr_in6 *)(addr))->sin6_addr, name, size);
+        inet_ntop(addr->sa_family, &((const struct sockaddr_in6 *)(addr))->sin6_addr, name, size);
         return name;
 #endif
     case AF_INET:
-        inet_ntop(addr->sa_family, &((struct sockaddr_in *)(addr))->sin_addr, name, size);
+        inet_ntop(addr->sa_family, &((const struct sockaddr_in *)(addr))->sin_addr, name, size);
         return name;
 #else
     case AF_INET:
         ENTER_EXCLUSIVE
-        string::set(name, size, inet_ntoa(((struct sockaddr_in *)(addr))->sin_addr));
+        String::set(name, size, inet_ntoa(((const struct sockaddr_in *)(addr))->sin_addr));
         LEAVE_EXCLUSIVE
         return name;
 #endif
@@ -2975,17 +2973,17 @@ char *Socket::getaddress(struct sockaddr *addr, char *name, socklen_t size)
     return NULL;
 }
 
-int Socket::getinterface(struct sockaddr *iface, struct sockaddr *dest)
+int Socket::via(struct sockaddr *iface, const struct sockaddr *dest)
 {
     assert(iface != NULL);
     assert(dest != NULL);
 
     int rtn = -1;
     socket_t so = INVALID_SOCKET;
-    socklen_t len = getlen(dest);
+    socklen_t slen = len(dest);
 
-    if(len)
-        memset(iface, 0, len);
+    if(slen)
+        memset(iface, 0, slen);
 
     iface->sa_family = AF_UNSPEC;
     switch(dest->sa_family) {
@@ -2997,8 +2995,8 @@ int Socket::getinterface(struct sockaddr *iface, struct sockaddr *dest)
         if((socket_t)so == INVALID_SOCKET)
             return -1;
         socket_mapping(dest->sa_family, so);
-        if(!_connect_(so, dest, len))
-            rtn = _getsockname_(so, iface, &len);
+        if(!_connect_(so, dest, slen))
+            rtn = _getsockname_(so, iface, &slen);
         break;
     default:
         return ENOSYS;
@@ -3028,7 +3026,7 @@ int Socket::getinterface(struct sockaddr *iface, struct sockaddr *dest)
     return rtn;
 }
 
-bool Socket::subnet(struct sockaddr *s1, struct sockaddr *s2)
+bool Socket::eq_subnet(const struct sockaddr *s1, const struct sockaddr *s2)
 {
     assert(s1 != NULL && s2 != NULL);
 
@@ -3039,8 +3037,8 @@ bool Socket::subnet(struct sockaddr *s1, struct sockaddr *s2)
     if(s1->sa_family != AF_INET)
         return true;
 
-    a1 = (unsigned char *)&(((struct sockaddr_in *)(s1))->sin_addr);
-    a2 = (unsigned char *)&(((struct sockaddr_in *)(s1))->sin_addr);
+    a1 = (unsigned char *)&(((const struct sockaddr_in *)(s1))->sin_addr);
+    a2 = (unsigned char *)&(((const struct sockaddr_in *)(s1))->sin_addr);
 
     if(*a1 == *a2 && *a1 < 128)
         return true;
@@ -3060,7 +3058,7 @@ bool Socket::subnet(struct sockaddr *s1, struct sockaddr *s2)
     return true;
 }
 
-unsigned Socket::store(struct sockaddr_internet *storage, struct sockaddr *address)
+unsigned Socket::store(struct sockaddr_internet *storage, const struct sockaddr *address)
 {
     if(storage == NULL || address == NULL)
         return 0;
@@ -3080,20 +3078,20 @@ unsigned Socket::store(struct sockaddr_internet *storage, struct sockaddr *addre
     return 0;
 }
 
-unsigned Socket::copy(struct sockaddr *s1, struct sockaddr *s2)
+unsigned Socket::copy(struct sockaddr *s1, const struct sockaddr *s2)
 {
     if(s1 == NULL || s2 == NULL)
         return 0;
 
-    socklen_t len = getlen(s1);
+    socklen_t slen = len(s1);
     if(len > 0) {
-        memcpy(s1, s2, len);
-        return len;
+        memcpy(s1, s2, slen);
+        return slen;
     }
     return 0;
 }
 
-bool Socket::equalhost(struct sockaddr *s1, struct sockaddr *s2)
+bool Socket::eq_host(const struct sockaddr *s1, const struct sockaddr *s2)
 {
     assert(s1 != NULL && s2 != NULL);
 
@@ -3102,21 +3100,21 @@ bool Socket::equalhost(struct sockaddr *s1, struct sockaddr *s2)
 
     switch(s1->sa_family) {
     case AF_INET:
-        if(memcmp(&(((struct sockaddr_in *)s1)->sin_addr),
-            &(((struct sockaddr_in *)s2)->sin_addr), 4))
+        if(memcmp(&(((const struct sockaddr_in *)s1)->sin_addr),
+            &(((const struct sockaddr_in *)s2)->sin_addr), 4))
                 return false;
 
         return true;
 #ifdef  AF_INET6
     case AF_INET6:
-        if(memcmp(&(((struct sockaddr_in6 *)s1)->sin6_addr),
-            &(((struct sockaddr_in6 *)s2)->sin6_addr), 4))
+        if(memcmp(&(((const struct sockaddr_in6 *)s1)->sin6_addr),
+            &(((const struct sockaddr_in6 *)s2)->sin6_addr), 4))
                 return false;
 
         return true;
 #endif
     default:
-        if(memcmp(s1, s2, getlen(s1)))
+        if(memcmp(s1, s2, len(s1)))
             return false;
         return true;
     }
@@ -3124,7 +3122,7 @@ bool Socket::equalhost(struct sockaddr *s1, struct sockaddr *s2)
 }
 
 
-bool Socket::equal(struct sockaddr *s1, struct sockaddr *s2)
+bool Socket::equal(const struct sockaddr *s1, const struct sockaddr *s2)
 {
     assert(s1 != NULL && s2 != NULL);
 
@@ -3133,33 +3131,33 @@ bool Socket::equal(struct sockaddr *s1, struct sockaddr *s2)
 
     switch(s1->sa_family) {
     case AF_INET:
-        if(memcmp(&(((struct sockaddr_in *)s1)->sin_addr),
-            &(((struct sockaddr_in *)s2)->sin_addr), 4))
+        if(memcmp(&(((const struct sockaddr_in *)s1)->sin_addr),
+            &(((const struct sockaddr_in *)s2)->sin_addr), 4))
                 return false;
 
-        if(!((struct sockaddr_in *)s1)->sin_port || !((struct sockaddr_in *)s2)->sin_port)
+        if(!((const struct sockaddr_in *)s1)->sin_port || !((const struct sockaddr_in *)s2)->sin_port)
             return true;
 
-        if(((struct sockaddr_in *)s1)->sin_port != ((struct sockaddr_in *)s2)->sin_port)
+        if(((const struct sockaddr_in *)s1)->sin_port != ((const struct sockaddr_in *)s2)->sin_port)
             return false;
 
         return true;
 #ifdef  AF_INET6
     case AF_INET6:
-        if(memcmp(&(((struct sockaddr_in6 *)s1)->sin6_addr),
-            &(((struct sockaddr_in6 *)s2)->sin6_addr), 4))
+        if(memcmp(&(((const struct sockaddr_in6 *)s1)->sin6_addr),
+            &(((const struct sockaddr_in6 *)s2)->sin6_addr), 4))
                 return false;
 
-        if(!((struct sockaddr_in6 *)s1)->sin6_port || !((struct sockaddr_in6 *)s2)->sin6_port)
+        if(!((const struct sockaddr_in6 *)s1)->sin6_port || !((const struct sockaddr_in6 *)s2)->sin6_port)
             return true;
 
-        if(((struct sockaddr_in6 *)s1)->sin6_port != ((struct sockaddr_in6 *)s2)->sin6_port)
+        if(((const struct sockaddr_in6 *)s1)->sin6_port != ((const struct sockaddr_in6 *)s2)->sin6_port)
             return false;
 
         return true;
 #endif
     default:
-        if(memcmp(s1, s2, getlen(s1)))
+        if(memcmp(s1, s2, len(s1)))
             return false;
         return true;
     }
@@ -3194,7 +3192,7 @@ ssize_t Socket::printf(socket_t so, const char *format, ...)
     return sendto(so, buf, strlen(buf), 0, NULL);
 }
 
-socklen_t Socket::getlen(struct sockaddr *sa)
+socklen_t Socket::len(const struct sockaddr *sa)
 {
     if(!sa)
         return 0;
@@ -3212,7 +3210,7 @@ socklen_t Socket::getlen(struct sockaddr *sa)
     }
 }
 
-int Socket::getfamily(socket_t so)
+int Socket::family(socket_t so)
 {
     assert(so != INVALID_SOCKET);
 
@@ -3230,7 +3228,7 @@ int Socket::getfamily(socket_t so)
     return us.inaddr.sin_family;
 }
 
-bool Socket::isNull(const char *str)
+bool Socket::is_null(const char *str)
 {
     assert(str != NULL);
 
@@ -3247,7 +3245,7 @@ bool Socket::isNull(const char *str)
     return true;
 }
 
-bool Socket::isNumeric(const char *str)
+bool Socket::is_numeric(const char *str)
 {
     assert(str != NULL);
 
@@ -3268,70 +3266,18 @@ bool Socket::isNumeric(const char *str)
     return true;
 }
 
-int Socket::getlocal(socket_t sock, struct sockaddr_storage *addr)
+int Socket::local(socket_t sock, struct sockaddr_storage *addr)
 {
     socklen_t slen = sizeof(sockaddr_storage);
     return _getsockname_(sock, (struct sockaddr *)addr, &slen);
 }
 
-int Socket::getremote(socket_t sock, struct sockaddr_storage *addr)
+int Socket::remote(socket_t sock, struct sockaddr_storage *addr)
 {
     socklen_t slen = sizeof(sockaddr_storage);
     return _getpeername_(sock, (struct sockaddr *)addr, &slen);
 }
 
-int Socket::select(int max, set_t read, set_t write, set_t error)
-{
-    return _select_(max, (fd_set *)read, (fd_set *)write, (fd_set *)error, NULL);
-}
-
-int Socket::select(int max, set_t read, set_t write, set_t error, timeout_t timeout)
-{
-    struct timeval tv;
-    struct timeval *tvp = &tv;
-
-    if(timeout == Timer::inf)
-        tvp = NULL;
-    else {
-        tv.tv_usec = (timeout % 1000) * 1000;
-        tv.tv_sec = timeout / 1000;
-    }
-
-    return _select_(max, (fd_set *)read, (fd_set *)write, (fd_set *)error, tvp);
-}
-
-Socket::set_t Socket::getmask(void)
-{
-    set_t mask = (set_t)malloc(sizeof(fd_set));
-    clear(mask);
-    return mask;
-}
-
-void Socket::clear(set_t mask)
-{
-    FD_ZERO((fd_set *)mask);
-}
-
-void Socket::set(socket_t sock, set_t mask)
-{
-    FD_SET(sock, (fd_set *)mask);
-}
-
-void Socket::clear(socket_t sock, set_t mask)
-{
-    FD_CLR(sock, (fd_set *)mask);
-}
-
-bool Socket::test(socket_t sock, set_t mask)
-{
-    return FD_ISSET(sock, (fd_set *)mask) != 0;
-}
-
-void Socket::release(set_t mask)
-{
-    free(mask);
-}
-
 String str(Socket& so, strsize_t size)
 {
     String s(size);
