@@ -228,6 +228,12 @@ public:
     inline operator fd_t() const
         {return fd;}
 
+    /**
+     * Reset error flag.
+     */
+    inline void reset(void)
+        {error = 0;}
+
     /**
      * Test if file descriptor is open.
      * @return true if open.
@@ -771,6 +777,9 @@ public:
     inline int err(void) const
         {return fsys::err();}
 
+    inline void reset(void)
+        {fsys::reset();}
+
     /**
      * Test if file descriptor is open.
      * @return true if open.
