@@ -490,6 +490,40 @@ template<>
 inline void dupfree<char*>(char* object)
     {::free(object);}
 
+/**
+ * Convenience function to reset an existing object.
+ * @param object type to reset.
+ */
+template<typename T>
+inline void reset_unsafe(T& object)
+    {new((caddr_t)&object) T;}
+
+/**
+ * Convenience function to zero an object and restore type info.
+ * @param object to zero in memory.
+ */
+template<typename T>
+inline void zero_unsafe(T& object)
+    {memset((void *)&object, 0, sizeof(T)); new((caddr_t)&object) T;}
+
+/**
+ * Convenience function to copy class.
+ * @param target to copy into.
+ * @param source to copy from.
+ */
+template<typename T>
+inline void copy_unsafe(T* target, const T* source)
+    {memcpy((void *)target, (void *)source, sizeof(T));}
+
+/**
+ * Convenience function to store object pointer into object.
+ * @param target to copy into.
+ * @param source to copy from.
+ */
+template<typename T>
+inline void store_unsafe(T& target, const T* source)
+    {memcpy((void *)&target, (void *)source, sizeof(T));}
+
 /**
  * Convenience function to swap objects.
  * @param o1 to swap.
@@ -523,6 +557,19 @@ inline T& (min)(T& o1, T& o2)
     return o1 < o2 ? o1 : o2;
 }
 
+/**
+ * Convenience macro to range restrict values.
+ * @param value to check.
+ * @param low value.
+ * @param high value.
+ * @return adjusted value.
+ */
+template<typename T>
+inline T& (limit)(T& value, T& low, T& high)
+{
+    return (value < low) ? low : ((value > high) ? high : value);
+}
+
 END_NAMESPACE
 
 #endif
