@@ -57,7 +57,7 @@ class PagerPool;
  * performance.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT memalloc : public MemoryProtocol, protected LockingProtocol
+class __EXPORT memalloc : public MemoryProtocol
 {
 private:
     friend class bufpager;
@@ -84,6 +84,11 @@ protected:
      */
     page_t *pager(void);
 
+    /**
+     * Report runtime memory exhaustion.
+     */
+    virtual void fault(void) const;
+
 public:
     /**
      * Construct a memory pager.
@@ -100,8 +105,8 @@ public:
      * Get the number of pages that have been allocated from the real heap.
      * @return pages allocated from heap.
      */
-    inline unsigned getPages(void)
-        {return count;};
+    inline unsigned pages(void) const
+        {return count;}
 
     /**
      * Get the maximum number of pages that are permitted.  One can use a
@@ -110,15 +115,15 @@ public:
      * to detect and bring down apps that are leaking.
      * @return page allocation limit.
      */
-    inline unsigned getLimit(void)
-        {return limit;};
+    inline unsigned max(void) const
+        {return limit;}
 
     /**
      * Get the size of a memory page.
      * @return size of each pager heap allocation.
      */
-    inline unsigned getAlloc(void)
-        {return pagesize;};
+    inline unsigned size(void) const
+        {return pagesize;}
 
     /**
      * Determine fragmentation level of acquired heap pages.  This is
@@ -130,7 +135,7 @@ public:
      * may suggest a larger page size should be used.
      * @return pager utilization.
      */
-    unsigned utilization(void);
+    unsigned utilization(void) const;
 
     /**
      * Purge all allocated memory and heap pages immediately.
@@ -167,7 +172,7 @@ public:
  * insufficient space in the current page to complete a request.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT mempager : public memalloc
+class __EXPORT mempager : public memalloc, public LockingProtocol
 {
 private:
     pthread_mutex_t mutex;
@@ -235,7 +240,7 @@ public:
     virtual void *_alloc(size_t size);
 };
 
-class __EXPORT objectpager : protected memalloc
+class __EXPORT ObjectPager : protected memalloc
 {
 public:
     class __EXPORT member : public LinkedObject
@@ -244,10 +249,13 @@ public:
         void *mem;
 
     protected:
-        friend class objectpager;
+        friend class ObjectPager;
 
         inline void set(member *node)
-            {next = node;};
+            {Next = node;};
+
+        inline void *get(void) const
+            {return mem;};
 
         member(LinkedObject **root);
         member();
@@ -255,9 +263,6 @@ public:
     public:
         inline void *operator*() const
             {return mem;};
-
-        inline void *get(void) const
-            {return mem;};
     };
 
 private:
@@ -268,7 +273,7 @@ private:
     void **index;
 
 protected:
-    objectpager(size_t objsize, size_t pagesize = 256);
+    ObjectPager(size_t objsize, size_t pagesize = 256);
 
     /**
      * Get object from list.  This is useful when objectpager is
@@ -276,7 +281,7 @@ protected:
      * @param item to access.
      * @return pointer to text for item, or NULL if out of range.
      */
-    void *get(unsigned item);
+    void *get(unsigned item) const;
 
     /**
      * Add object to list.
@@ -298,6 +303,12 @@ protected:
      */
     void *pop(void);
 
+    /**
+     * Invalid object...
+     * @return typically NULL.
+     */
+    void *invalid(void) const;
+
 public:
     /**
      * Purge all members and release pager member.  The list can then
@@ -310,22 +321,33 @@ public:
      * the list of strings.
      * @return first member of list or NULL if empty.
      */
-    inline objectpager::member *begin(void)
-        {return static_cast<objectpager::member *>(root);};
+    inline ObjectPager::member *begin(void)
+        {return static_cast<ObjectPager::member *>(root);};
 
-    inline operator bool()
+    inline operator bool() const
         {return members > 0;}
 
-    inline bool operator!()
+    inline bool operator!() const
         {return !members;}
 
     /**
      * Get the number of items in the pager string list.
      * @return number of items stored.
      */
-    inline unsigned count(void)
+    inline unsigned count(void) const
         {return members;};
 
+    /**
+     * Convenience typedef for iterative pointer.
+     */
+    typedef linked_pointer<ObjectPager::member> iterator;
+
+    inline size_t size(void)
+        {return memalloc::size();}
+
+    inline unsigned pages(void)
+        {return memalloc::pages();}
+
 protected:
     /**
      * Gather index list.
@@ -339,16 +361,28 @@ protected:
  * used for accumulating lists which can be destroyed all at once.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT stringpager : protected memalloc
+class __EXPORT StringPager : protected memalloc
 {
 private:
     unsigned members;
     LinkedObject *root;
 
+protected:
+    virtual const char *invalid(void) const;
+
 public:
+    /**
+     * Filter text in a derived class.  The base class filter removes
+     * newlines at end of text and filters out empty strings.
+     * @param text to filter.
+     * @param size of text buffer for transforms.
+     * @return false if end of data.
+     */
+    virtual bool filter(char *text, size_t size);
+
     /**
      * Member of string list.  This is exposed so that the list of strings
-     * can be externally enumerated with linked_pointer<stringpager::member>
+     * can be externally enumerated with linked_pointer<StringPager::member>
      * if so desired, through the begin() method.
      * @author David Sugar <dyfet@gnutelephony.org>
      */
@@ -358,10 +392,10 @@ public:
         const char *text;
 
     protected:
-        friend class stringpager;
+        friend class StringPager;
 
         inline void set(member *node)
-            {next = node;};
+            {Next = node;};
 
         member(LinkedObject **root, const char *data);
         member(const char *data);
@@ -378,24 +412,24 @@ public:
      * Create a pager with a maximum page size.
      * @param size of pager allocation pages.
      */
-    stringpager(size_t pagesize = 256);
+    StringPager(size_t pagesize = 256);
 
-    stringpager(char **list, size_t pagesize = 256);
+    StringPager(char **list, size_t pagesize = 256);
 
     /**
      * Get the number of items in the pager string list.
      * @return number of items stored.
      */
-    inline unsigned count(void)
+    inline unsigned count(void) const
         {return members;};
 
     /**
-     * Get string item from list.  This is useful when stringpager is
+     * Get string item from list.  This is useful when StringPager is
      * passed as a pointer and hence inconvenient for the [] operator.
      * @param item to access.
      * @return pointer to text for item, or NULL if out of range.
      */
-    const char *get(unsigned item);
+    const char *get(unsigned item) const;
 
     /**
      * Replace string item in list.
@@ -460,7 +494,10 @@ public:
      * @param item to access.
      * @return text of item or NULL if invalid.
      */
-    inline const char *operator[](unsigned item)
+    inline const char *operator[](unsigned item) const
+        {return get(item);};
+
+    inline const char *at(unsigned item) const
         {return get(item);};
 
     /**
@@ -468,8 +505,8 @@ public:
      * the list of strings.
      * @return first member of list or NULL if empty.
      */
-    inline stringpager::member *begin(void)
-        {return static_cast<stringpager::member *>(root);};
+    inline StringPager::member *begin(void) const
+        {return static_cast<StringPager::member *>(root);};
 
     /**
      * Convenience operator to add to pager and auto-sort.
@@ -482,10 +519,10 @@ public:
      * Convenience operator to add to pager.
      * @param text to add to list.
      */
-    inline stringpager& operator<<(const char *text)
+    inline StringPager& operator<<(const char *text)
         {add(text); return *this;}
 
-    inline stringpager& operator>>(const char *text)
+    inline StringPager& operator>>(const char *text)
         {push(text); return *this;}
 
     /**
@@ -500,7 +537,7 @@ public:
     char **list(void);
 
     /**
-     * Tokenize a string and add each token to the stringpager.
+     * Tokenize a string and add each token to the StringPager.
      * @param text to tokenize.
      * @param list of characters to use as token separators.
      * @param quote pairs of characters for quoted text or NULL if not used.
@@ -521,7 +558,7 @@ public:
     inline bool operator!()
         {return !members;}
 
-    inline stringpager& operator=(char **list)
+    inline StringPager& operator=(char **list)
         {set(list); return *this;}
 
     inline const char *operator*()
@@ -530,6 +567,17 @@ public:
     inline operator char **()
         {return list();};
 
+    /**
+     * Convenience typedef for iterative pointer.
+     */
+    typedef linked_pointer<StringPager::member> iterator;
+
+    inline size_t size(void)
+        {return memalloc::size();}
+
+    inline unsigned pages(void)
+        {return memalloc::pages();}
+
 private:
     member *last;
     char **index;
@@ -542,17 +590,19 @@ private:
  * include in the list.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT DirPager : protected stringpager
+class __EXPORT DirPager : protected StringPager
 {
 protected:
     const char *dir;
 
     /**
-     * Filter filenames in a derived class.
+     * Filter filenames in a derived class.  The default filter
+     * drops "." special files.
      * @param filename to filter.
+     * @param size of filename buffer.
      * @return true if include in final list.
      */
-    virtual bool filter(const char *filename);
+    virtual bool filter(char *filename, size_t size);
 
     /**
      * Load a directory path.
@@ -568,26 +618,38 @@ public:
 
     void operator=(const char *path);
 
-    inline const char *operator*()
+    inline const char *operator*() const
         {return dir;};
 
-    inline operator bool()
+    inline operator bool() const
         {return dir != NULL;};
 
-    inline bool operator!()
+    inline bool operator!() const
         {return dir == NULL;};
 
+    inline unsigned count(void) const
+        {return StringPager::count();};
+
     /**
      * Return specified filename from directory list.  This is a convenience
      * operator.
      * @param item to access.
      * @return text of item or NULL if invalid.
      */
-    inline const char *operator[](unsigned item)
-        {return stringpager::get(item);};
+    inline const char *operator[](unsigned item) const
+        {return StringPager::get(item);};
 
-    inline const char *get(unsigned item)
-        {return stringpager::get(item);};
+    inline const char *get(unsigned item) const
+        {return StringPager::get(item);};
+
+    inline const char *at(unsigned item) const
+        {return StringPager::get(item);};
+
+    inline size_t size(void)
+        {return memalloc::size();}
+
+    inline unsigned pages(void)
+        {return memalloc::pages();}
 };
 
 /**
@@ -606,6 +668,7 @@ private:
     cpage_t *first, *last, *current, *freelist;
     unsigned cpos;
     unsigned long ccount;
+    bool eom;       /* null written or out of memory */
 
     virtual int _getch(void);
     virtual int _putch(int code);
@@ -661,7 +724,7 @@ public:
      * Get total size.
      * @return number of characters in buffer.
      */
-    inline unsigned long getUsed(void)
+    inline unsigned long used(void) const
         {return ccount;}
 
     /**
@@ -680,13 +743,40 @@ public:
 
     bufpager(size_t page = 0);
 
+    /**
+     * Request character buffer to write into directly.
+     * @param iosize made available.
+     * @return pointer to buffer or NULL if out of memory.
+     */
     char *request(size_t *iosize);
 
+    /**
+     * Get pointer to copy character data.  The memory pointer is
+     * positioned at the next chunk automatically.
+     * @param iosize of data you can copy.
+     * @return to data from buffer or NULL if past end.
+     */
     char *copy(size_t *iosize);
 
-    void release(void);
+    /**
+     * Used to complete a request method.
+     * @param size of data actually written.
+     */
+    void update(size_t size);
 
-    void commit(size_t size);
+    /**
+     * Check if can still save into buffer.
+     * @return true if buffer is full.
+     */
+    inline bool operator!()
+        {return eom;}
+
+    /**
+     * Check if can still save into buffer.  Used for is() function.
+     * @return true if pager can still store more.
+     */
+    inline operator bool()
+        {return !eom;}
 };
 
 /**
@@ -748,6 +838,11 @@ protected:
      */
     PagerObject();
 
+    /**
+     * Reset state of object.
+     */
+    void reset(void);
+
     /**
      * Release a pager object reference.
      */
@@ -855,12 +950,12 @@ private:
         void *data;
         char text[8];
 
-        keydata(keyassoc *assoc, char *id, unsigned max, unsigned bufsize);
+        keydata(keyassoc *assoc, const char *id, unsigned max, unsigned bufsize);
     };
 
     friend class keydata;
 
-    unsigned count;
+    unsigned keycount;
     unsigned paths;
     size_t keysize;
     NamedObject **root;
@@ -873,7 +968,7 @@ protected:
      * @param size of object to allocate.
      * @return pointer to allocated object or NULL on failure.
      */
-    void *allocate(char *name, size_t size);
+    void *allocate(const char *name, size_t size);
 
 public:
     /**
@@ -893,8 +988,8 @@ public:
      * Get the number of associations we have in our object.
      * @return number of associations stored.
      */
-    inline unsigned getCount(void)
-        {return count;};
+    inline unsigned count(void) const
+        {return keycount;};
 
     /**
      * Lookup the data pointer of a string by direct operation.
@@ -923,7 +1018,7 @@ public:
      * @param pointer value to assign with name.
      * @return false if failed because name is too long for managed table.
      */
-    bool assign(char *name, void *pointer);
+    bool assign(const char *name, void *pointer);
 
     /**
      * Create a new name in the association table and assign it's value.
@@ -931,7 +1026,7 @@ public:
      * @param pointer value to assign with name.
      * @return false if already exists or name is too long for managed table.
      */
-    bool create(char *name, void *pointer);
+    bool create(const char *name, void *pointer);
 
     /**
      * Remove a name and pointer association.  If managed key names are used
@@ -943,46 +1038,46 @@ public:
 };
 
 template <class T, size_t P = 0>
-class listof : private objectpager
+class listof : private ObjectPager
 {
 public:
-    inline listof() : objectpager(sizeof(T), P) {};
+    inline listof() : ObjectPager(sizeof(T), P) {};
 
     inline T& operator[](unsigned item) const
-        {return (T&)objectpager::get(item);}
+        {return (T&)ObjectPager::get(item);}
 
     inline T* operator()(unsigned item) const
-        {return (T*)objectpager::get(item);}
+        {return (T*)ObjectPager::get(item);}
 
-    inline T* get(unsigned item) const
-        {return (T*)objectpager::get(item);}
+    inline const T& at(unsigned item) const
+        {return (const T&)ObjectPager::get(item);}
 
     inline T* pull(void)
-        {return (T*)objectpager::pull();}
+        {return (T*)ObjectPager::pull();}
 
     inline T* pop(void)
-        {return (T*)objectpager::pop();}
+        {return (T*)ObjectPager::pop();}
 
     inline operator T**()
-        {return (T**)objectpager::list();}
+        {return (T**)ObjectPager::list();}
 
     inline T** list(void)
-        {return (T**)objectpager::list();}
+        {return (T**)ObjectPager::list();}
 
     inline T* operator++(void)
-        {T* tmp = objectpager::add(); if(tmp) new((caddr_t)tmp) T; return tmp;}
+        {T* tmp = ObjectPager::add(); if(tmp) new((caddr_t)tmp) T; return tmp;}
 
     inline T* add(const T& object)
-        {T* tmp = objectpager::add(); if(tmp) new((caddr_t)tmp) T(object); return tmp;}
+        {T* tmp = ObjectPager::add(); if(tmp) new((caddr_t)tmp) T(object); return tmp;}
 
     inline T* push(const T& object)
-        {T* tmp = objectpager::push(); if(tmp) new((caddr_t)tmp) T(object); return tmp;}
+        {T* tmp = ObjectPager::push(); if(tmp) new((caddr_t)tmp) T(object); return tmp;}
 
     inline listof& operator<<(const T& object)
-        {T* tmp = objectpager::add(); if(tmp) new((caddr_t)tmp) T(object); return *this;}
+        {T* tmp = ObjectPager::add(); if(tmp) new((caddr_t)tmp) T(object); return *this;}
 
     inline listof& operator>>(const T& object)
-        {T* tmp = objectpager::push(); if(tmp) new((caddr_t)tmp) T(object); return *this;}
+        {T* tmp = ObjectPager::push(); if(tmp) new((caddr_t)tmp) T(object); return *this;}
 
 };
 
@@ -999,8 +1094,8 @@ public:
      * Get the count of typed objects stored in our hash map.
      * @return typed objects in map.
      */
-    inline unsigned getCount(void)
-        {return keyassoc::getCount();};
+    inline unsigned count(void) const
+        {return keyassoc::count();};
 
     /**
      * Purge the hash map of typed objects.
@@ -1031,7 +1126,7 @@ public:
      * Create mapped entry from scratch.
      * @param name to assign.
      */
-    inline T *map(char *name)
+    inline T *map(const char *name)
         {T *tmp = keyassoc::allocate(name, sizeof(T)); if(tmp) new((caddr_t)tmp) T;}
 
     /**
@@ -1039,7 +1134,7 @@ public:
      * used then the memory allocated for the name will be re-used.
      * @param name to remove.
      */
-    inline void unmap(char *name)
+    inline void unmap(const char *name)
         {keyassoc::remove(name);};
 
     /**
@@ -1056,8 +1151,8 @@ public:
      * privately.
      * @return count of heap pages used.
      */
-    inline unsigned getPages(void)
-        {return mempager::getPages();};
+    inline unsigned pages(void) const
+        {return mempager::pages();};
 };
 
 /**
@@ -1080,8 +1175,8 @@ public:
      * Get the count of typed objects stored in our hash map.
      * @return typed objects in map.
      */
-    inline unsigned getCount(void)
-        {return keyassoc::getCount();}
+    inline unsigned count(void) const
+        {return keyassoc::count();}
 
     /**
      * Purge the hash map of typed objects.
@@ -1141,7 +1236,7 @@ public:
      * inherit keyassoc privately.
      * @return pager utilization, 0-100.
      */
-    inline unsigned utilization(void)
+    inline unsigned utilization(void) const
         {return mempager::utilization();}
 
     /**
@@ -1150,8 +1245,8 @@ public:
      * privately.
      * @return count of heap pages used.
      */
-    inline unsigned getPages(void)
-        {return mempager::getPages();}
+    inline unsigned pages(void) const
+        {return mempager::pages();}
 };
 
 /**
@@ -1170,12 +1265,6 @@ public:
      */
     inline pager(mempager *heap = NULL) : MemoryRedirect(heap), PagerPool() {};
 
-    /**
-     * Purge managed objects.
-     */
-    inline ~pager()
-        {mempager::purge();};
-
     /**
      * Create a managed object by casting reference.
      * @return pointer to typed managed pager pool object.
@@ -1286,17 +1375,22 @@ public:
      */
     inline T **sort(void) const
         {return NamedObject::sort(NamedObject::index(idx, M));};
+
+    /**
+     * Convenience typedef for iterative pointer.
+     */
+    typedef linked_pointer<T> iterator;
 };
 
 /**
  * A convenience type for paged string lists.
  */
-typedef stringpager stringlist_t;
+typedef StringPager stringlist_t;
 
 /**
  * A convenience type for paged string list items.
  */
-typedef stringpager::member stringlistitem_t;
+typedef StringPager::member stringlistitem_t;
 
 /**
  * A convenience type for using DirPager directly.
@@ -1310,7 +1404,7 @@ inline void unshift(stringlist_t& list, const char *text)
     {list.push(text);}
 
 
-inline String str(stringpager& list, const char *prefix = NULL, const char *middle = NULL, const char *suffix = NULL)
+inline String str(StringPager& list, const char *prefix = NULL, const char *middle = NULL, const char *suffix = NULL)
     {return list.join(prefix, middle, suffix);}
 
 END_NAMESPACE
