@@ -541,6 +541,11 @@ public:
      */
     void lower(void);
 
+    /**
+     * Erase string memory.
+     */
+    void erase(void);
+
     /**
      * Count number of occurrences of characters in string.
      * @param list of characters to find.
@@ -972,6 +977,12 @@ public:
      */
     static void fix(String& object);
 
+    /**
+     * Erase string memory.  Often used to clear out passwords.
+     * @param text string to erase.
+     */
+    static void erase(char *text);
+
     /**
      * Convert null terminated text to lower case.
      * @param text to convert.
@@ -1468,7 +1479,7 @@ public:
      * Create a new character buffer with an empty string.
      */
     inline charbuf()
-        {buffer[0] = 0;};
+        {buffer[0] = 0;}
 
     /**
      * Create a character buffer with assigned text.  If the text is
@@ -1476,14 +1487,20 @@ public:
      * @param text to assign.
      */
     inline charbuf(const char *text)
-        {String::set(buffer, S, text);};
+        {String::set(buffer, S, text);}
+
+    /**
+     * Copy constructor.
+     */
+    inline charbuf(const charbuf& copy)
+        {String::set(buffer, S, copy.buffer);}
 
     /**
      * Assign null terminated text to the object.
      * @param text to assign.
      */
     inline void operator=(const char *text)
-        {String::set(buffer, S, text);};
+        {String::set(buffer, S, text);}
 
     /**
      * Concatenate text into the object.  If the text is larger than the
@@ -1491,21 +1508,21 @@ public:
      * @param text to append.
      */
     inline void operator+=(const char *text)
-        {String::add(buffer, S, text);};
+        {String::add(buffer, S, text);}
 
     /**
      * Test if data is contained in the object.
      * @return true if there is text.
      */
     inline operator bool() const
-        {return buffer[0];};
+        {return buffer[0];}
 
     /**
      * Test if the object is empty.
      * @return true if the object is empty.
      */
     inline bool operator!() const
-        {return buffer[0] == 0;};
+        {return buffer[0] == 0;}
 
     /**
      * Get text by casting reference.
@@ -1526,8 +1543,8 @@ public:
      * @param offset of character in string buffer.
      * @return character at offset.
      */
-    inline char operator[](size_t offset) const
-        {return buffer[offset];};
+    inline char& operator[](size_t offset) const
+        {return buffer[offset];}
 
     /**
      * Get a pointer to an offset in the object by expression operator.
@@ -1535,14 +1552,21 @@ public:
      * @return pointer to offset in object.
      */
     inline char *operator()(size_t offset)
-        {return buffer + offset;};
+        {return buffer + offset;}
 
     /**
      * Get allocated size of the object.
      * @return allocated size.
      */
     inline size_t size(void) const
-        {return S;};
+        {return S;}
+
+    /**
+     * Get current length of string.
+     * @return length of string.
+     */
+    inline size_t len(void) const
+        {return strlen(buffer);}
 };
 
 /**
