@@ -94,76 +94,15 @@ size_t Random::fill(unsigned char *buf, size_t size)
 #endif
 }
 
-int Random::get(void)
-{
-    uint16_t v;;
-    fill((unsigned char *)&v, sizeof(v));
-    v /= 2;
-    return (int)v;
-}
-
-int Random::get(int min, int max)
-{
-    unsigned rand;
-    int range = max - min + 1;
-    unsigned umax;
-
-    if(max < min)
-        return 0;
-
-    memset(&umax, 0xff, sizeof(umax));
-
-    do {
-        fill((unsigned char *)&rand, sizeof(rand));
-    } while(rand > umax - (umax % range));
-
-    return min + (rand % range);
-}
-
-double Random::real(void)
-{
-    unsigned umax;
-    unsigned rand;
-
-    memset(&umax, 0xff, sizeof(umax));
-    fill((unsigned char *)&rand, sizeof(rand));
-
-    return ((double)rand) / ((double)umax);
-}
-
-double Random::real(double min, double max)
-{
-    return real() * (max - min) + min;
-}
-
 bool Random::status(void)
 {
 #ifdef  _MSWINDOWS_
     return true;
 #else
-    if(fsys::isfile("/dev/random"))
+    if(fsys::is_file("/dev/random"))
         return true;
 
     return false;
 #endif
 }
 
-void Random::uuid(char *str)
-{
-    unsigned char buf[16];
-
-    fill(buf, sizeof(buf));
-    buf[6] &= 0x0f;
-    buf[6] |= 0x40;
-    buf[8] &= 0x3f;
-    buf[8] |= 0x80;
-    String::hexdump(buf, str, "4-2-2-2-6");
-}
-
-String Random::uuid(void)
-{
-    char buf[38];
-    uuid(buf);
-    return String(buf);
-}
-
