@@ -104,20 +104,20 @@ static void scrub(const char *path)
     if(is(verbose))
         shell::printf("%s", path);
 
-    int err = fsys::fileinfo(path, &ino);
+    int err = fsys::info(path, &ino);
 
-    if(err == ENOENT || fsys::islink(path)) {
+    if(err == ENOENT || fsys::is_link(path)) {
         report(path, fsys::unlink(path));
         return;
     }
 
-    if(fsys::isdir(&ino)) {
-        report(path, fsys::removeDir(path));
+    if(fsys::is_dir(&ino)) {
+        report(path, dir::remove(path));
         return;
     }
 
-    if(err == ENOENT || !ino.st_size || fsys::issys(&ino) || fsys::isdev(&ino)) {
-        report(path, fsys::remove(path));
+    if(err == ENOENT || !ino.st_size || fsys::is_sys(&ino) || fsys::is_dev(&ino)) {
+        report(path, fsys::erase(path));
         return;
     }
 
@@ -125,7 +125,7 @@ static void scrub(const char *path)
     count /= (fsys::offset_t)(*blocks);
     count *= (fsys::offset_t)(*blocks);
 
-    fs.open(path, fsys::ACCESS_REWRITE);
+    fs.open(path, fsys::REWRITE);
     if(!is(fs)) {
         report(path, fs.err());
         return;
@@ -186,7 +186,7 @@ repeat:
         }
     }
 
-    report(path, fsys::remove(path));
+    report(path, dir::remove(path));
 
     fs.close();
 
@@ -196,16 +196,16 @@ static void scan(String path, bool top = true)
 {
     char filename[128];
     String filepath;
-    fsys_t dir(path, fsys::ACCESS_DIRECTORY);
+    dir_t dir(path);
 
-    while(is(dir) && fsys::read(dir, filename, sizeof(filename))) {
+    while(is(dir) && dir.read(filename, sizeof(filename))) {
         if(*filename == '.' && (filename[1] == '.' || !filename[1]))
             continue;
 
         filepath = str(path) + str("/") + str(filename);
-        if(fsys::isdir(filepath)) {
+        if(fsys::is_dir(filepath)) {
             if(is(follow) || is(recursive) || is(altrecursive)) {
-                if(fsys::islink(filepath) && !is(follow))
+                if(fsys::is_link(filepath) && !is(follow))
                     scrub(filepath);
                 else
                     scan(filepath, false);
@@ -251,7 +251,7 @@ PROGRAM_MAIN(argc, argv)
     secure::init();
 
     while(count < args()) {
-        if(fsys::isdir(args[count]))
+        if(fsys::is_dir(args[count]))
             scan(str(args[count++]));
         else
             scrub(args[count++]);
